@@ -26,10 +26,10 @@
 
 extern gchar *cdrecord_get_mediainfo(Tgrave *Ag, Tdriveinfo *Adevice, GError **Aerror);
 extern gchar *burn_data_getextrapara(Tgrave *Ag);
-extern int scan_for_drives(Tgrave *Ag, GError **Aerror);
+extern int cdrecord_scan_for_drives(Tgrave *Ag, GError **Aerror);
 extern gboolean burn_from_image(gchar *Aop, Tgrave *Ag, GError **Aerror);
 extern gboolean gravepiste(Tgrave *Ag, GError **Aerror);
-extern gboolean maj_drive_info(Tdriveinfo *Adrive, gchar *Adev, GError **Aerror);
+extern gboolean cdrecord_maj_drive_info(Tdriveinfo *Adrive, gchar *Adev, GError **Aerror);
 extern gboolean perform_fix_cd(Tgrave *Ag, GError **Aerror);
 extern void eject_cd(gchar *Adev, GError **Aerror);
 extern gboolean perform_erase_cdrw(Tgrave *Ag, GError **Aerror);
