@@ -25,7 +25,8 @@
 #ifndef _G_GROWISOFS_H
 #define _G_GROWISOFS_H
 
-extern gboolean burn_dvd(Tgrave *Ag, GError **Aerror);
+extern gboolean burn_data2dvd(Tgrave *Ag, GError **Aerror);
+extern gboolean burn_iso2dvd(Tgrave *Ag, GError **Aerror);
 
 #endif
 
