@@ -24,7 +24,7 @@
 #ifndef _G_MAIN_H
 #define _G_MAIN_H
 
-extern GladeXML *Gxml;
+extern gchar *Glocale;
 
 #endif
 
