@@ -224,21 +224,31 @@ void gtk_data_creerrepertoire(GtkWidget *btn, gpointer Adata)
 }
 
 /* developper tout le contenu de l'arbre */
-void gtk_data_expandelement(GtkWidget *btn, gpointer Adata)
+void gtk_data_expandelement(GtkWidget *Abtn, gpointer Adata)
 {
   Tgrave *Lg = (Tgrave *)Adata;
-  GtkTreeView *Lliste = GTK_TREE_VIEW(sc_grave_get_data(Lg, "_current_list"));
-  GtkTreePath *Lpath = NULL;
+  GtkTreeView *Llist = GTK_TREE_VIEW(sc_grave_get_data(Lg, "_current_list"));
 
-  gtk_tree_view_get_cursor(Lliste, &Lpath, NULL);
-  if (!Lpath) return;
+  if (!GTK_IS_TREE_VIEW(Llist)) return;
 
-  gtk_tree_view_expand_row(Lliste, Lpath, TRUE);
-  gtk_tree_path_free(Lpath);
+  expand_list_icons(Llist, TRUE);
+}
+
+gboolean callback_simpledialog_eventkeyrelease(GtkWidget *Aentry, GdkEventKey *Aevent, gpointer Adata)
+{
+  GtkDialog *Ldialog = GTK_DIALOG(Adata);
+
+  if (!Aevent) return FALSE;
+  if (Aevent->keyval == GDK_Return) {
+    gtk_dialog_response(Ldialog, GTK_RESPONSE_OK);
+    return TRUE;
+  }
+
+  return FALSE;
 }
 
 /* renommer un element (fichier ou repertoire) */
-void gtk_data_renommerelement(GtkWidget *Abtn, gpointer Adata)
+void callbacks_data_renameitem(GtkWidget *Abtn, gpointer Adata)
 {
   Tgrave *Lg = (Tgrave *)Adata;
   GtkTreeView *Lliste = GTK_TREE_VIEW(sc_grave_get_data(Lg, "_current_list"));
@@ -263,10 +273,12 @@ void gtk_data_renommerelement(GtkWidget *Abtn, gpointer Adata)
   Lboite = gtk_dialog_new_with_buttons(Ltitle, NULL, GTK_DIALOG_MODAL,
         GTK_STOCK_OK,GTK_RESPONSE_OK, GTK_STOCK_CANCEL,GTK_RESPONSE_CANCEL, NULL);
   g_free(Ltitle);
+  gtk_dialog_set_default_response(GTK_DIALOG(Lboite), GTK_RESPONSE_OK);
 
   Lentry = gtk_entry_new();
   gtk_entry_set_text(GTK_ENTRY(Lentry), Lname);
   g_free(Lname);
+  g_signal_connect(G_OBJECT(Lentry), "key-release-event", G_CALLBACK(callback_simpledialog_eventkeyrelease), Lboite);
 
   gtk_box_pack_start(GTK_BOX(GTK_DIALOG(Lboite)->vbox), Lentry, TRUE, FALSE, 0);
   gtk_widget_show_all(GTK_DIALOG(Lboite)->vbox);
@@ -718,8 +730,10 @@ void gtk_devices_add(GtkWidget *Abtn, gpointer Adata)
       GtkEntry *Ldevicename = GTK_ENTRY(sc_grave_get_widget(Ldialoghash, "devicename"));
       gchar *Lbus = (gchar *)gtk_entry_get_text(Ldevicebus);
       Tdriveinfo *Ldrive = g_malloc0(sizeof(Tdriveinfo));
-    
-      maj_drive_info(Ldrive, Lbus, NULL);
+ 
+      proc_init_cdrominfo(NULL);
+      matos_maj_drive_info(Ldrive, Lbus, NULL);
+      proc_free_cdrominfo();
 
       if (Ldrive->type == 0) {
         Lmessage = gtk_message_dialog_new(GTK_WINDOW(Lparent),
@@ -911,7 +925,7 @@ void confirm_fixcd(GtkWidget *Abtn, gpointer Adata)
   GSList *Llmediarequis = g_slist_append(NULL, GINT_TO_POINTER(_MEDIA_CDR + _MEDIA_NOBLANK + _MEDIA_APPENDABLE));
   gboolean Lstatus;
   
-  Lstatus = waiting_for_user(_MEDIA_TITLE_BLANKORAPPENDABLE, Lg, Llmediarequis, NULL, get_drive_info(Lg, "dstothercombo"));
+  Lstatus = waiting_for_user(_MEDIA_TITLE_BLANKORAPPENDABLE, Lg, Llmediarequis, NULL, matos_get_drive_info(Lg, "dstothercombo"));
   g_slist_free(Llmediarequis);
   
   if (Lstatus==FALSE) return;
@@ -989,7 +1003,7 @@ void confirm_erasecdrw(GtkWidget *Abtn, gpointer Adata)
   GtkWidget *Lconfirm;
   GSList *Llmediarequis = g_slist_append(NULL, GINT_TO_POINTER(_MEDIA_CDRW + _MEDIA_NOBLANK));
   gboolean Lstatus;
-  Lstatus = waiting_for_user(_MEDIA_TITLE_BLANKORAPPENDABLE, Lg, Llmediarequis, NULL, get_drive_info(Lg, "dstothercombo"));
+  Lstatus = waiting_for_user(_MEDIA_TITLE_BLANKORAPPENDABLE, Lg, Llmediarequis, NULL, matos_get_drive_info(Lg, "dstothercombo"));
   g_slist_free(Llmediarequis);
   
   if (Lstatus==FALSE) return;
@@ -1056,7 +1070,7 @@ void confirm_burn (GtkWidget *Abtn, gpointer Adata)
     }
     Ltxt = _("Do you really want to create an audio cd ?");
     Ltitle = _("Writing audio cd in progress...");
-    Ldevicename1 = get_drive_info(Lg, "dstaudiocombo");
+    Ldevicename1 = matos_get_drive_info(Lg, "dstaudiocombo");
     Llmediarequis1 = manage_mediarequis(NULL,
                       _MEDIA_CDR + _MEDIA_BLANK, _MEDIA_CDR + _MEDIA_APPENDABLE,
                       _MEDIA_CDRW + _MEDIA_BLANK, _MEDIA_CDRW + _MEDIA_APPENDABLE,
@@ -1084,7 +1098,7 @@ void confirm_burn (GtkWidget *Abtn, gpointer Adata)
     }
 
     if (Loperation == WRITE_CD) {
-      Ldevicename1 = get_drive_info(Lg, "dstdatacombo");
+      Ldevicename1 = matos_get_drive_info(Lg, "dstdatacombo");
       Liso = !Ldevicename1;
       if (Liso) {
         Ltxt = _("Do you really want to create an iso image ?");
@@ -1105,7 +1119,7 @@ void confirm_burn (GtkWidget *Abtn, gpointer Adata)
         Ltitle = _("Writing iso image in progress...");
       }
     } else {
-      Ldevicename1 = get_drive_info(Lg, "dstdvddatacombo");
+      Ldevicename1 = matos_get_drive_info(Lg, "dstdvddatacombo");
       Liso = !Ldevicename1;
       if (!Liso) {
         Ltxt = _("Do you really want to create a data dvd ?");
@@ -1127,13 +1141,13 @@ void confirm_burn (GtkWidget *Abtn, gpointer Adata)
 
     Ltxt = _("Do you really want to start the copy ?");
     Ltitle = _("Copying in progress...");
-    Ldevicename1 = get_drive_info(Lg, "srccopycombo");
+    Ldevicename1 = matos_get_drive_info(Lg, "srccopycombo");
     Liso = !Ldevicename1;
     if (!Liso) {
       Llmediarequis1 = manage_mediarequis(NULL, _MEDIA_CD + _MEDIA_NOBLANK, -1);
       Lmediatitle1 = _MEDIA_CD;
     }
-    Ldevicename2 = get_drive_info(Lg, "dstcopycombo");
+    Ldevicename2 = matos_get_drive_info(Lg, "dstcopycombo");
 
     if (Ldevicename2) {
       Llmediarequis2 = manage_mediarequis(NULL, 
@@ -1309,6 +1323,17 @@ gboolean gtk_do_eventkeyrelease(GtkWidget *Aliste, GdkEventKey *Aevent, gpointer
       gtk_data_addfile(NULL, Lg);
       return TRUE;
     }
+
+  } else if (Aevent->keyval == GDK_F2) {
+    /* appuis sur F2, renommer un element */
+    if (!strcmp(Lname, "LISTEDATA") || !strcmp(Lname, "LISTEDVDDATA")) {
+      callbacks_data_renameitem(NULL, Lg);
+    }
+  } else if ((Aevent->keyval >= GDK_exclam && Aevent->keyval <= GDK_EuroSign) ||
+             (Aevent->keyval >= GDK_KP_0 && Aevent->keyval <= GDK_KP_9)) {
+    guint Lkey = Aevent->keyval >=GDK_KP_0 ? Aevent->keyval - 0xFF80 : Aevent->keyval;
+
+    callbacks_try_to_select(Lkey, GTK_TREE_VIEW(Aliste), Lg);
   }
 
   return FALSE;
@@ -1600,7 +1625,8 @@ void cherchelecteur(GtkWidget *Aobj, gpointer Adata)
   gtk_widget_show(Lwin);
   Ltimeout = g_timeout_add(500, encours_callback, Lg);
 
-  scan_for_drives(Lg, NULL);
+  proc_init_cdrominfo(NULL);
+  cdrecord_scan_for_drives(Lg, NULL);
 
   if (Labort == FALSE) {
     for (Lcur = Glistdrives; Lcur; Lcur = Lcur ? g_slist_next(Lcur) : Lnext) {
@@ -1610,7 +1636,7 @@ void cherchelecteur(GtkWidget *Aobj, gpointer Adata)
         gtk_label_set_text(GTK_LABEL(sc_grave_get_widget(Lg, "labelava")), Ltxt); g_free(Ltxt);
         while(gtk_events_pending()) gtk_main_iteration();
 
-        maj_drive_info(Ldrive, (gchar *)g_slist_nth_data(Ldrive->dev, 0), NULL);
+        matos_maj_drive_info(Ldrive, NULL, NULL);
 
         /* on n'ajoute que les lecteurs/graveurs */
         if (Ldrive->type == 0) {
@@ -1622,6 +1648,7 @@ _DEB("le type == %d = %s\n", Ldrive->type, Ldrive->name);
       }
     }
   }
+  proc_free_cdrominfo();
 
   /* on attend la fin d'execution de la popup d'attente */
   g_source_remove(Ltimeout);
@@ -1648,7 +1675,7 @@ void abort_encours(GtkWidget *Abtn, gpointer Adata)
   gboolean *Labort = (gboolean *)sc_grave_get_data(Lg, "gabort");
   gint *Lpid = (gint *)sc_grave_get_data(Lg, "pid");
 printf(" on va kill !\n");
-  if (*Lpid) {
+  if (Lpid && *Lpid) {
     /* on envoi un TERM au process (cdrecord...) pour qu'il s'arrete ! */
 _DEB("kill de %d\n", *Lpid);
     kill(*Lpid, SIGINT);
@@ -2073,6 +2100,84 @@ void change_datamulti(GtkWidget *Amulti, gpointer Adata)
   gtk_widget_set_sensitive(GTK_WIDGET(Lspin), ! Lact);
 }
 
+/* select items begining with key user has pressed */
+gboolean callbacks_try_to_select(guint Akey, GtkTreeView *Aliste, Tgrave *Ag)
+{
+  GtkTreeModel *Ltreemodel = gtk_tree_view_get_model(GTK_TREE_VIEW(Aliste));
+  GtkTreePath *Lpath = NULL;
+  gchar *Lname;
+  GtkTreeIter Liter;
+  gboolean Ltrouve = FALSE;
+  gboolean Lfirstiteration = TRUE;
+  gboolean Lskip = FALSE;
+
+  gtk_tree_view_get_cursor(Aliste, &Lpath, NULL);
+  if (!Lpath) return FALSE;
+
+  while (1) {
+    while (1) {
+      if (Lskip == FALSE) {
+        gtk_tree_path_next(Lpath);
+      } else {
+        Lskip = FALSE;
+      }
+      if (!gtk_tree_model_get_iter(Ltreemodel, &Liter, Lpath)) break;
+
+      gtk_tree_model_get(Ltreemodel, &Liter, 2, &Lname, -1);
+      if (!Lname) continue;
+
+      if (*(tools_next_no_char(Lname, (gchar ) GDK_space)) == Akey) {
+        Ltrouve = TRUE;
+        break;
+      }
+    }
+
+    if (Lfirstiteration == FALSE || Ltrouve == TRUE) {
+      break;
+    } else {
+      Lfirstiteration = FALSE;
+      while (gtk_tree_path_prev(Lpath)) ;
+      Lskip = TRUE;
+    }
+  }
+
+  if (Ltrouve) {
+    gtk_tree_view_scroll_to_cell(GTK_TREE_VIEW(Aliste), Lpath, NULL, FALSE, 0, 0);
+    gtk_tree_view_set_cursor(GTK_TREE_VIEW(Aliste), Lpath, NULL, TRUE);
+  }
+
+  gtk_tree_path_free(Lpath);
+
+  return Ltrouve;
+}
+
+/* gestion des tris */
+void callbacks_data_asksort(GtkWidget *Abtn, gpointer Adata)
+{
+  Tgrave *Lg = (Tgrave *)Adata;
+  GtkTreeView *Lliste = GTK_TREE_VIEW(sc_grave_get_data(Lg, "_current_list"));
+  GtkTreeModel *Ltreemodel = gtk_tree_view_get_model(GTK_TREE_VIEW(Lliste));
+  GtkTreeSortable *Lsort = NULL;
+/*  gint Lcolid;
+  GtkSortType Lorder;*/
+  const gchar *Lname;
+
+  if (!GTK_IS_WIDGET(Abtn) || !GTK_IS_WIDGET(Lliste)) return;
+  Lsort = GTK_TREE_SORTABLE(Ltreemodel);
+
+  if ((!(Lname = gtk_widget_get_name(Abtn))) || strlen(Lname)<10) return;
+
+/*  if (!gtk_tree_sortable_get_sort_column_id(GTK_TREE_SORTABLE(Lmodel), &Lcolid, &Lorder)) return;*/
+  if (strstr(Lname, "_name")) {
+    gtk_tree_sortable_set_sort_column_id(Lsort, 2, GTK_SORT_ASCENDING);
+  } else if (strstr(Lname, "_size")) {
+    gtk_tree_sortable_set_sort_column_id(Lsort, 3, GTK_SORT_ASCENDING);
+  } else {
+    gtk_tree_sortable_set_sort_column_id(Lsort, 0, GTK_SORT_ASCENDING);
+  }
+
+}
+
 /* definir/enlever l'image de boot */
 #if 0
 void gtk_def_imageboot(GtkWidget *Abtn, gpointer Adata)
