@@ -40,6 +40,7 @@
 #define CDRECORD_FIXATING "Fixating..."
 #define CDRECORD_BLANKING "Blanking "
 #define CDRECORD_BAD_RECORDER "Sorry, no CD/DVD-Recorder or unsupported CD/DVD-Recorder found"
+#define CDRECORD_CANNOT_OPEN "Cannot open"
 
 /* support du materiel */
 #define CDRECORD_NOT_READ_CD "Does not read CD-R media"
@@ -52,7 +53,6 @@
 #define CDRECORD_WRITE_DVD "Does write DVD-R media"
 #define CDRECORD_NOT_WRITE_DVD "Does not write DVD-R media"
 #define CDRECORD_NOT_WRITE_DUMMY "Does not support test writing"
-#define CDRECORD_WRITE_DUMMY "Does support test writing"
 #define CDRECORD_MAX_CDREAD_SPEED "Maximum read  speed:"
 #define CDRECORD_MAX_CDREAD_SPEED_CD "(CD"
 #define CDRECORD_MAX_CDREAD_SPEED_DVD " DVD "
@@ -67,6 +67,7 @@
 
 /* definition de tous les type de bus */
 Tsearchdrive listesearchdrives[] = {
+    { "", "", "SCSI", 110 }, /* scsi (sg) */
 #if LINUX_IDE /* pure ide devices with linux */
     { "dev=/dev/hda", "/dev/hda", "IDE", 100 },
     { "dev=/dev/hdb", "/dev/hdb", "IDE", 100 },
@@ -80,15 +81,35 @@ Tsearchdrive listesearchdrives[] = {
     { "dev=/dev/hdj", "/dev/hdj", "IDE", 100 },
 #endif
 #if LINUX_SCSI  /* SCSI alias with linux */
-    { "dev=/dev/scd0", "/dev/scd0", "DSCSI", 90 },
-    { "dev=/dev/scd1", "/dev/scd1", "DSCSI", 90 },
-    { "dev=/dev/scd2", "/dev/scd2", "DSCSI", 90 },
-    { "dev=/dev/scd3", "/dev/scd3", "DSCSI", 90 },
-    { "dev=/dev/scd4", "/dev/scd4", "DSCSI", 90 },
-    { "dev=/dev/scd5", "/dev/scd5", "DSCSI", 90 },
-    { "dev=/dev/scd6", "/dev/scd6", "DSCSI", 90 },
+    { "dev=/dev/scd0", "/dev/scd0", "SCSI-D", 90 },
+    { "dev=/dev/scd1", "/dev/scd1", "SCSI-D", 90 },
+    { "dev=/dev/scd2", "/dev/scd2", "SCSI-D", 90 },
+    { "dev=/dev/scd3", "/dev/scd3", "SCSI-D", 90 },
+    { "dev=/dev/scd4", "/dev/scd4", "SCSI-D", 90 },
+    { "dev=/dev/scd5", "/dev/scd5", "SCSI-D", 90 },
+    { "dev=/dev/scd6", "/dev/scd6", "SCSI-D", 90 },
+    { "dev=/dev/sr0", "/dev/sr0",  "SCSI-S", 92 },
+    { "dev=/dev/sr1", "/dev/sr1",  "SCSI-S", 92 },
+    { "dev=/dev/sr2", "/dev/sr2",  "SCSI-S", 92 },
+    { "dev=/dev/sr3", "/dev/sr3",  "SCSI-S", 92 },
+    { "dev=/dev/sr4", "/dev/sr4",  "SCSI-S", 92 },
+    { "dev=/dev/sr5", "/dev/sr5",  "SCSI-S", 92 },
+    { "dev=/dev/sr6", "/dev/sr6",  "SCSI-S", 92 },
+    { "dev=/dev/sg0", "/dev/sg0",  "SCSI-G", 94 },
+    { "dev=/dev/sg1", "/dev/sg1",  "SCSI-G", 94 },
+    { "dev=/dev/sg2", "/dev/sg2",  "SCSI-G", 94 },
+    { "dev=/dev/sg3", "/dev/sg3",  "SCSI-G", 94 },
+    { "dev=/dev/sg4", "/dev/sg4",  "SCSI-G", 94 },
+    { "dev=/dev/sg5", "/dev/sg5",  "SCSI-G", 94 },
+    { "dev=/dev/sg6", "/dev/sg6",  "SCSI-G", 94 },
+    { "dev=/dev/sga", "/dev/sga",  "SCSI-g", 96 },
+    { "dev=/dev/sgb", "/dev/sgb",  "SCSI-g", 96 },
+    { "dev=/dev/sgc", "/dev/sgc",  "SCSI-g", 96 },
+    { "dev=/dev/sgd", "/dev/sgd",  "SCSI-g", 96 },
+    { "dev=/dev/sge", "/dev/sge",  "SCSI-g", 96 },
+    { "dev=/dev/sgf", "/dev/sgf",  "SCSI-g", 96 },
+    { "dev=/dev/sgg", "/dev/sgg",  "SCSI-g", 96 },
 #endif
-    { "", "", "SCSI", 80 }, /* scsi (sg) */
     { "dev=ATA:", "ATA:", "ATA", 60 }, /* ide sg */
     { "dev=ATAPI:", "ATAPI:", "ATAPI", 40 }, /* ide */
     { NULL, NULL, NULL, 0}
@@ -117,7 +138,7 @@ static gchar *get_title(gint Anbrgravure, gint Acurcd, gboolean Adosimul)
 }
 
 /* recherche des lecteurs */
-gboolean extractlecteur(gchar *Achaine, gchar **Adev, gchar **Amarque, gchar **Amodel,
+gboolean cdrecord_extractlecteur(gchar *Achaine, gchar **Adev, gchar **Amarque, gchar **Amodel,
   gchar **Aquoi)
 {
   gchar *s = Achaine;
@@ -170,9 +191,14 @@ gboolean scan_callback(GIOChannel *Astd, GIOCondition Acond, gpointer Adata)
     
   g_strstrip(Lbuffer);  
 _DEB("scan lecteur = %s\n", Lbuffer);
-  if (extractlecteur(Lbuffer, &Ldev, &Lmarque, &Lmodel, &Lquoi) == TRUE) {
+  if (strstr(Lbuffer, CDRECORD_CANNOT_OPEN)) {
+    *Lcont = 2;
+    return FALSE;
+  }
 
-    insert_or_update_drive(Ldev, Lmarque, Lmodel, Lquoi, Ldrivedesc);
+  if (cdrecord_extractlecteur(Lbuffer, &Ldev, &Lmarque, &Lmodel, &Lquoi) == TRUE) {
+
+    matos_insert_or_update_drive(Ldev, Lmarque, Lmodel, Lquoi, Ldrivedesc);
 
     _DEB("oui un lecteur");
     
@@ -188,7 +214,7 @@ _DEB("scan lecteur = %s\n", Lbuffer);
 }
 
 /* scan des lecteurs */
-gboolean scan_for_drives(Tgrave *Ag, GError **Aerror)
+gboolean cdrecord_scan_for_drives(Tgrave *Ag, GError **Aerror)
 {
   gchar **Lcmd;
   gchar *Lcommandline;
@@ -200,9 +226,10 @@ gboolean scan_for_drives(Tgrave *Ag, GError **Aerror)
   Tsearchdrive *Lcurentry;
   gint *Lcont = (gint *)sc_grave_get_data(Ag, "cont");
   gboolean *Labort = (gboolean *)sc_grave_get_data(Ag, "gabort");
-  
+
   free_drives(FALSE);
   for (Lcurentry = listesearchdrives; Lcurentry->detectline && *Labort == FALSE; Lcurentry++) {
+
     Lcommandline = g_strdup_printf("%s -scanbus %s", conf_get_string("cdrecord"), Lcurentry->detectline);
   _DEB("commande =%s\n", Lcommandline);
     Lstatus = g_shell_parse_argv(Lcommandline, &Lnbrarg, &Lcmd, Aerror);
@@ -244,15 +271,15 @@ gboolean scan_for_drives(Tgrave *Ag, GError **Aerror)
 }
 
 /* mise a jour capacit du lecteur */
-gboolean maj_drive_info(Tdriveinfo *Adrive, gchar *Adev, GError **Aerror)
+gboolean cdrecord_maj_drive_info(Tdriveinfo *Adrive, gchar *Adev, GError **Aerror)
 {
   gchar *Lcommandline, *Lout = NULL, *Lerr = NULL;
   gchar *scd = NULL, *sdvd = NULL, *f;
   gint Lexit = 0;
   gboolean Lstatus;
-  gint Ltype = 0;
 
-  Lcommandline = g_strdup_printf("%s -prcap dev=%s", conf_get_string("cdrecord"), Adev);
+  Lcommandline = g_strdup_printf("%s -prcap dev=%s", conf_get_string("cdrecord"),
+      Adev ? Adev : DRIVE_DEV(Adrive));
 
 _DEB("==================%s\n", Lcommandline);  
   Lstatus = g_spawn_command_line_sync(Lcommandline, &Lout, &Lerr, &Lexit, Aerror);
@@ -263,12 +290,11 @@ _DEB("==================%s\n", Lcommandline);
     return FALSE;
   }
 
-  if (strstr(Lout, CDRECORD_READ_CD)) Ltype += _READ_CDR;
-  if (strstr(Lout, CDRECORD_WRITE_CDR)) Ltype += _WRITE_CDR;
-  if (strstr(Lout, CDRECORD_WRITE_CDRW)) Ltype += _WRITE_CDRW;
-  if (strstr(Lout, CDRECORD_WRITE_DUMMY)) Ltype += _WRITE_DUMMY;
-  if (strstr(Lout, CDRECORD_READ_DVD)) Ltype += _READ_DVD;
-  if (strstr(Lout, CDRECORD_WRITE_DVD)) Ltype += _WRITE_DVD;
+  if (strstr(Lout, CDRECORD_READ_CD)) Adrive->type |= _READ_CDR;
+  if (strstr(Lout, CDRECORD_WRITE_CDR)) Adrive->type |= _WRITE_CDR;
+  if (strstr(Lout, CDRECORD_WRITE_CDRW)) Adrive->type |= _WRITE_CDRW;
+  if (strstr(Lout, CDRECORD_READ_DVD)) Adrive->type |= _READ_DVD;
+  if (strstr(Lout, CDRECORD_WRITE_DVD)) Adrive->type |= _WRITE_DVD;
 
   /* vitesse de lecture maximum CD */
   if ((scd=strstr(Lout, CDRECORD_MAX_CDREAD_SPEED))) {
@@ -293,21 +319,21 @@ _DEB("==================%s\n", Lcommandline);
 
   if (!scd) return FALSE;
 
-  Adrive->type = Ltype; /* type: lecteur ou graveur */
   Adrive->vitesse = atoi(scd);  /* vitesse de lecture ou de gravure maximum */
   Adrive->vitessedvd = sdvd ? atoi(sdvd) : -1;
-  _DEB("== le type => %d\n", Ltype);
+  _DEB("== le type => %d\n", Adrive->type);
   _DEB("== donc la vitesse de lecture => %d\n", Adrive->vitesse  );
 
 
   /* ok maintenant on regarde si le lecteur supporte le burnfree, si oui on l'utilisera
    * lors des gravures */
-  Lcommandline = g_strdup_printf("%s -checkdrive dev=%s driveropts=help", conf_get_string("cdrecord"), Adev);
+  Lcommandline = g_strdup_printf("%s -checkdrive dev=%s driveropts=help", conf_get_string("cdrecord"),
+      Adev ? Adev : DRIVE_DEV(Adrive));
 _DEB("==================%s\n", Lcommandline);  
   Lstatus = g_spawn_command_line_sync(Lcommandline, &Lout, &Lerr, &Lexit, Aerror);
   g_free(Lcommandline);
   if (Lstatus == TRUE) {
-    if (strstr(Lout, CDRECORD_BURNFREE)) Ltype += _BURN_FREE;
+    if (strstr(Lout, CDRECORD_BURNFREE)) Adrive->type |= _BURN_FREE;
   }
   g_free(Lout);
   g_free(Lerr);
@@ -375,7 +401,7 @@ gboolean burn_from_image(gchar *Aop, Tgrave *Ag, GError **Aerror) {
 
   g_snprintf(Lgravident, sizeof(Lgravident)-1, "dst%scombo", Aop);
 
-  Ldevice = get_drive_info(Ag, Lgravident);
+  Ldevice = matos_get_drive_info(Ag, Lgravident);
   
   Lbufvitesse = get_combo_value(Lvitesse);
 
@@ -441,6 +467,10 @@ gboolean burn_from_image(gchar *Aop, Tgrave *Ag, GError **Aerror) {
     g_free(Ltxt);
 
     Lblank = get_blank_type(Ag, Lmediadetect1);
+
+    /* try to umount device before device access */
+    matos_umount_device(Ldevice, NULL);
+
     Lcommandline = g_strdup_printf("%s dev=%s -v gracetime=2 %s%s %s %s %s %s %s %s %s %s '%s' %s",
         conf_get_string("cdrecord"), DRIVE_DEV(Ldevice),
         *Lbufvitesse != '0' ? "speed=" : "", *Lbufvitesse != '0' ? Lbufvitesse : "",  
@@ -770,7 +800,7 @@ gboolean gravepiste(Tgrave *Ag, GError **Aerror) {
   gint g_out, g_err, Lnbrarg;
   gboolean Lstatus = FALSE;
   gchar *Lbufvitesse;
-  Tdriveinfo *Ldevice = get_drive_info(Ag, "dstaudiocombo");
+  Tdriveinfo *Ldevice = matos_get_drive_info(Ag, "dstaudiocombo");
   gboolean Lsimul = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(sc_grave_get_widget(Ag, "audiosimul")));
   gboolean Lnotfix = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(sc_grave_get_widget(Ag, "audionotfix")));
   gboolean Ldaomode = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(sc_grave_get_widget(Ag, "audiodao")));
@@ -868,6 +898,9 @@ _DEB("execution [%s]\n", Lcommandline);
       break;
     }
 
+    /* try to umount device before device access */
+    matos_umount_device(Ldevice, NULL);
+
     Lstatus = g_spawn_async_with_pipes(Lrepertoire, Lcmd, NULL, /* env argument */
         (GSpawnFlags ) (G_SPAWN_DO_NOT_REAP_CHILD),
         NULL, NULL, Lpid, NULL, &g_out, &g_err, Aerror);
@@ -1006,7 +1039,7 @@ gboolean perform_fix_cd(Tgrave *Ag, GError **Aerror)
   guint Lcomevent, Lcomerrevent;
   gint g_out, g_err, Lnbrarg;
   gint *Lcont = sc_grave_get_data(Ag, "cont");
-  Tdriveinfo *Ldevice = get_drive_info(Ag, "dstothercombo");
+  Tdriveinfo *Ldevice = matos_get_drive_info(Ag, "dstothercombo");
 
   /* pid de cdrecord */
   gint *Lpid = (gint *) sc_grave_get_data(Ag, "pid");
@@ -1021,6 +1054,9 @@ gboolean perform_fix_cd(Tgrave *Ag, GError **Aerror)
     return FALSE;
   }
 
+  /* try to umount device before device access */
+  matos_umount_device(Ldevice, NULL);
+
   Lstatus = g_spawn_async_with_pipes(NULL, Lcmd, NULL, /* env argument */
       (GSpawnFlags ) (G_SPAWN_DO_NOT_REAP_CHILD),
        NULL, NULL, Lpid, NULL, &g_out, &g_err, Aerror);
@@ -1085,7 +1121,7 @@ gboolean perform_erase_cdrw(Tgrave *Ag, GError **Aerror)
   guint Lcomevent, Lcomerrevent;
   gint g_out, g_err, Lnbrarg;
   gint *Lcont = sc_grave_get_data(Ag, "cont");
-  Tdriveinfo *Ldevice = get_drive_info(Ag, "dstothercombo");
+  Tdriveinfo *Ldevice = matos_get_drive_info(Ag, "dstothercombo");
   gboolean *Lfastblank = sc_grave_get_data(Ag, "usefastblank");
 
   /* pid de cdrecord */
@@ -1102,6 +1138,9 @@ gboolean perform_erase_cdrw(Tgrave *Ag, GError **Aerror)
     return FALSE;
   }
 
+  /* try to umount device before device access */
+  matos_umount_device(Ldevice, NULL);
+
   Lstatus = g_spawn_async_with_pipes(NULL, Lcmd, NULL, /* env argument */
       (GSpawnFlags ) (G_SPAWN_DO_NOT_REAP_CHILD),
        NULL, NULL, Lpid, NULL, &g_out, &g_err, Aerror);
