@@ -56,8 +56,9 @@ TProgRequis Glisteprogrequis[] = {
   { CONF_STRING, "fastblank", "1", CONF_SAVEALWAYS },
   { CONF_STRING, "charsetdata", "DEFAULT", CONF_SAVEALWAYS },
   { CONF_STRING, "eject", "1", CONF_SAVEALWAYS },
-  { CONF_STRING, "iconsize", "24", CONF_SAVEALWAYS },
+  { CONF_STRING, "iconsize", "48", CONF_SAVEALWAYS },
   { CONF_STRING, "statusbar", "1", CONF_SAVEALWAYS },
+  { CONF_STRING, "tooltips", "1", CONF_SAVEALWAYS },
   { CONF_STRING, "saveconfig", "1", CONF_SAVEALWAYS },
 
   /* onglet audio */
@@ -104,6 +105,7 @@ TProgRequis Glisteprogrequis[] = {
 #endif
   { CONF_STRING, "version", "1", CONF_SAVEALWAYS },
   { CONF_STRING, "scan_drives", "0", CONF_SAVEALWAYS + CONF_PERSIST },
+  { CONF_STRING, "theme", "default", CONF_SAVEALWAYS },
   { CONF_IGNORE, NULL, NULL, 0 },
 };
 
@@ -167,11 +169,29 @@ void foreachdrives(gpointer Adrive, gpointer Adata)
   fprintf(Lfic, "manual=%d\n", Ldrive->manual == TRUE ? 1 : 0);
 }
 
+gchar *dump_file_list(char *Abuf, gint Asize)
+{
+  GSList *Llistconfig = get_config_path();
+  GSList *Lcurlist;
+
+  memset(Abuf, 0, Asize);
+
+  for (Lcurlist = Llistconfig; Lcurlist; Lcurlist = g_slist_next(Lcurlist)) {
+    if (*Abuf) strncat(Abuf, "\n", Asize-strlen(Abuf)-5);
+    strncat(Abuf, Lcurlist->data, Asize-strlen(Abuf)-5);
+  }
+
+  g_slist_free(Llistconfig);
+
+  return Abuf;
+}
+
 /* ecriture du fichier de configuration */
 gboolean write_conf(GError **Aerror)
 {
   FILE *Lfic;
   gchar *Ltmp;
+  
   if (!get_config_file(W_OK)) return FALSE;
 
   if (!(Lfic=fopen(Gfileconf, "w"))) {
@@ -208,9 +228,11 @@ void config_init()
   conf_store_value("fastblank", "1");
   conf_store_value("tmpdir", "/tmp");
   conf_store_value("lastdir", "");
-  conf_store_value("iconsize", "24");
+  conf_store_value("iconsize", "48");
   conf_store_value("statusbar", "1");
   conf_store_value("saveconfig", "1");
+  conf_store_value("tooltips", "1");
+  conf_store_value("theme", "default");
   if (s) {
     Gfifosize = atoi(s);
     if (Gfifosize<=0) Gfifosize=6;
@@ -218,7 +240,7 @@ void config_init()
 }
 
 /* on regarde si un fichier de configuration existe 
- * dans /usr/share/graveman/graveman.rc ou ~/.graveman/graveman.rc */
+ * tel que definie par http://standards.freedesktop.org/basedir-spec/latest/ */
 
 /* construction de la liste des PATH dans lequel on va chercher la configuration */
 GSList *get_config_path()
@@ -229,12 +251,22 @@ GSList *get_config_path()
   gchar **Llistpath;
   gint i;
 
+  /* parametre -c sur la ligne de commande */
+  if ((Lpath = param_get_string("config_file"))) {
+    Llistpath = g_strsplit(Lpath, ":", 0);
+
+    for (i=0; Llistpath[i]; i++) {
+      if (!*Llistpath[i]) continue; /* on ignore les entrees vides */
+      Lnewlist = g_slist_append(Lnewlist, g_strdup_printf(Llistpath[i]));
+    }
+
+    g_strfreev(Llistpath);
+  }
+  
   if ((Lenv=g_getenv("XDG_CONFIG_HOME"))) {
     Lpath = g_strdup_printf("%s/%s/%s.conf", Lenv, PACKAGE, PACKAGE);
     Lnewlist = g_slist_append(Lnewlist, Lpath);
-  }
-
-  if ((Lenv=g_getenv("HOME"))) {
+  } else if ((Lenv=g_getenv("HOME"))) {
     Lpath = g_strdup_printf("%s/.config/%s/%s.conf", Lenv, PACKAGE, PACKAGE);
     Lnewlist = g_slist_append(Lnewlist, Lpath);
   }
@@ -243,15 +275,73 @@ GSList *get_config_path()
     Llistpath = g_strsplit(Lenv, ":", 0);
 
     for (i=0; Llistpath[i]; i++) {
+      if (!*Llistpath[i]) continue; /* on ignore les entrees vides */
       Lpath = g_strdup_printf("%s/%s/%s.conf", Llistpath[i], PACKAGE, PACKAGE);
       Lnewlist = g_slist_append(Lnewlist, Lpath);
+    }
 
-      g_free(Lpath);
+    g_strfreev(Llistpath);
+
+  } else {
+    Lpath = g_strdup_printf("/etc/xdg/%s/%s.conf", PACKAGE, PACKAGE);
+    Lnewlist = g_slist_append(Lnewlist, Lpath);
+  }
+
+  return Lnewlist;
+}
+
+/* on regarde si un repertoire de donne existe
+ * tel que definie par http://standards.freedesktop.org/basedir-spec/latest/
+ * on regarde de + en dernier dans le DATADIR definie a la compilation
+ */
+
+/* construction de la liste des PATH dans lequel on va chercher la configuration */
+GSList *get_data_path()
+{
+  GSList *Lnewlist = NULL;
+  const gchar *Lenv;
+  gchar *Lpath;
+  gchar **Llistpath;
+  gint i;
+
+  /* parametre -c sur la ligne de commande */
+  if ((Lpath = param_get_string("data_file"))) {
+    Llistpath = g_strsplit(Lpath, ":", 0);
+
+    for (i=0; Llistpath[i]; i++) {
+      if (!*Llistpath[i]) continue; /* on ignore les entrees vides */
+      Lnewlist = g_slist_append(Lnewlist, g_strdup_printf(Llistpath[i]));
     }
 
     g_strfreev(Llistpath);
   }
 
+  if ((Lenv=g_getenv("XDG_DATA_HOME"))) {
+    Lpath = g_strdup_printf("%s/%s", Lenv, PACKAGE);
+    Lnewlist = g_slist_append(Lnewlist, Lpath);
+  } else if ((Lenv=g_getenv("HOME"))) {
+    Lpath = g_strdup_printf("%s/.local/share/%s", Lenv, PACKAGE);
+    Lnewlist = g_slist_append(Lnewlist, Lpath);
+  }
+
+  if ((Lenv = g_getenv("XDG_DATA_DIRS"))) {
+    Llistpath = g_strsplit(Lenv, ":", 0);
+
+    for (i=0; Llistpath[i]; i++) {
+      Lpath = g_strdup_printf("%s/%s", Llistpath[i], PACKAGE);
+      Lnewlist = g_slist_append(Lnewlist, Lpath);
+    }
+
+    g_strfreev(Llistpath);
+  }
+
+  Lpath = g_strdup_printf("/usr/local/share/%s", PACKAGE);
+  Lnewlist = g_slist_append(Lnewlist, Lpath);
+  Lpath = g_strdup_printf("/usr/share/%s", PACKAGE);
+  Lnewlist = g_slist_append(Lnewlist, Lpath);
+  Lpath = g_strdup_printf("%s/%s", DATA_DIR, PACKAGE);
+  Lnewlist = g_slist_append(Lnewlist, Lpath);
+
   return Lnewlist;
 }
 
@@ -264,6 +354,7 @@ gboolean get_config_file(gint Lmode)
   gchar *s;
   
   *Gfileconf = 0; 
+
   for (Lcurlist = Llistconfig; Lcurlist; Lcurlist = g_slist_next(Lcurlist)) {
     if (W_OK == Lmode) {
       g_strlcpy(Lonlyname, (gchar *)Lcurlist->data, sizeof(Lonlyname)-1);      
@@ -401,7 +492,8 @@ void manage_saveonexit_value(Tgrave *Ag)
       conf_store_value(Lcurentry->entry, get_combo_value(Lwidget));
     } else if (Lcurentry->level & CONF_DEVICE) {
       Tdriveinfo *Ldevice = get_combo_value(Lwidget);
-      conf_store_value(Lcurentry->entry, DRIVE_DEV(Ldevice));
+      if (Ldevice != NULL)
+        conf_store_value(Lcurentry->entry, DRIVE_DEV(Ldevice));
     } else if (Lcurentry->level & CONF_SPIN) {
       conf_store_int(Lcurentry->entry, gtk_spin_button_get_value(GTK_SPIN_BUTTON(Lwidget)));
     } else if (Lcurentry->level & CONF_CHECK) {
@@ -415,6 +507,7 @@ gboolean manage_config(Tgrave *Ag, gshort Aop, GError **Aerror)
 {
   TProgRequis *Lcurprog;
   gchar *Lprog;
+  gboolean Lstatus = TRUE;
   GtkWidget *Lwindow1 = sc_grave_get_widget(Ag, "topwindow");
 
   if (Aop & UPDATE_SAVEONEXIT_VALUE) {
@@ -479,10 +572,24 @@ gboolean manage_config(Tgrave *Ag, gshort Aop, GError **Aerror)
   }
 
   if (Aop & WRITE_CONFIG) {    
-    return write_conf(Aerror);
+    Lstatus = write_conf(Aerror);
+    if (!Lstatus) {
+      gchar Lbuf[_BUF_SIZE];
+      gchar *Lfullmsg = g_strdup_printf(_("Cannot save configuration file !\nI have tried on those files:\n%s"),
+          dump_file_list(Lbuf, sizeof(Lbuf)-1));
+      GtkWidget *Ldialog = gtk_message_dialog_new(GTK_IS_WIDGET(Lwindow1) ? GTK_WINDOW(Lwindow1) : NULL,
+         GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
+         Lfullmsg);
+      
+      g_warning("%s", Lfullmsg);
+
+      gtk_dialog_run(GTK_DIALOG(Ldialog));
+      gtk_widget_destroy(Ldialog);
+      g_free(Lfullmsg);
+    }
   }
 
-  return TRUE;
+  return Lstatus;
 }
 
 /* renvoi une valeur du fichier de configuration */
@@ -695,12 +802,12 @@ void maj_foreach_prog(gpointer Akey, gpointer Avalue, gpointer Adata)
 
     if (!strcmp((gchar *)Akey, "mkisofs") && FALSE == conf_get_boolean("mkisofs_support_isov2")) {
       /* mkisofs est bien la, mais pas de support ISO v2 */
-      gtk_image_set_from_pixbuf(GTK_IMAGE(Lobj), GiconeMITIGE);
+      gtk_image_set_from_pixbuf(GTK_IMAGE(Lobj), get_image("WARNIcon"));
       g_snprintf(Ltipstxt, sizeof(Ltipstxt)-1, _("%s was found but does not support ISO 9660 version 2, this function will be disabled."), (gchar *)Akey);
     } else if (!strcmp((gchar *)Akey, "sox") &&
         (FALSE == conf_get_boolean("sox_support_mp3") || FALSE == conf_get_boolean("sox_support_ogg"))) {
       /* sox est bien la, mais pas de support MP3 ou/et OGG */
-      gtk_image_set_from_pixbuf(GTK_IMAGE(Lobj), GiconeMITIGE);
+      gtk_image_set_from_pixbuf(GTK_IMAGE(Lobj), get_image("WARNIcon"));
       
       if (FALSE == conf_get_boolean("sox_support_mp3") && FALSE == conf_get_boolean("sox_support_ogg")) {
         g_snprintf(Ltipstxt, sizeof(Ltipstxt)-1, _("%s was found but does not support neither OGG or MP3 file format, those functions will be disabled."), (gchar *)Akey);
@@ -710,12 +817,12 @@ void maj_foreach_prog(gpointer Akey, gpointer Avalue, gpointer Adata)
         g_snprintf(Ltipstxt, sizeof(Ltipstxt)-1, _("%s was found but does not support OGG file format, this function will be disabled."), (gchar *)Akey);
       }
     } else {
-      gtk_image_set_from_pixbuf(GTK_IMAGE(Lobj), GiconeOK);
+      gtk_image_set_from_pixbuf(GTK_IMAGE(Lobj), get_image("OKIcon"));
       g_snprintf(Ltipstxt, sizeof(Ltipstxt)-1, _("%s was found."), (gchar *)Akey);
     }
     gtk_tooltips_set_tip(sc_grave_get_data(Lg, "_tooltips"), Lobjtips, Ltipstxt, Ltipstxt);
   } else {
-    gtk_image_set_from_pixbuf(GTK_IMAGE(Lobj), GiconePASOK);
+    gtk_image_set_from_pixbuf(GTK_IMAGE(Lobj), get_image("BADIcon"));
     gtk_widget_set_sensitive(GTK_WIDGET(Lobjentry), FALSE);
     gtk_label_set_text(GTK_LABEL(Lobjlbl), (gchar *)Akey);
     g_snprintf(Ltipstxt, sizeof(Ltipstxt)-1, _("%s was not found, some features of graveman will be disabled."), (gchar *)Akey);
@@ -797,7 +904,7 @@ void save_last_dir(GtkFileChooser *Awidget)
 gboolean test_version()
 {
   char *Lver = conf_get_string("confversion");
-  if (!Lver || (strcmp(Lver, VERSION) && strcmp(Lver, "0.3.9"))) {
+  if (!Lver || ((strcmp(Lver, VERSION)) && (strncmp(Lver, "0.3.12", 6)))) {
     gchar *Lerrmsg = g_strdup_printf(_("graveman update !\n\nYou must remove your old configuration file '%s'.\nThen you can restart graveman..\n\nThanks ! :-)"), Gfileconf);
     GtkWidget *Lerr = gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_WARNING,
                           GTK_BUTTONS_OK, Lerrmsg);
