@@ -107,7 +107,7 @@ gboolean perform_format_dvd(Tgrave *Ag, Ttypeformatdvd Aoperation, GError **Aerr
   gint *Lcont = sc_grave_get_data(Ag, "cont");
   gint *Lpid = (gint *) sc_grave_get_data(Ag, "pid");
   gboolean *Labort = (gboolean *)sc_grave_get_data(Ag, "gabort");
-  Tdriveinfo *Ldevice = get_drive_info(Ag, "dstothercombo");
+  Tdriveinfo *Ldevice = matos_get_drive_info(Ag, "dstothercombo");
 
   if (Aoperation == DVD_FORMAT) {
     Lmode = "";
@@ -124,7 +124,7 @@ gboolean perform_format_dvd(Tgrave *Ag, Ttypeformatdvd Aoperation, GError **Aerr
   }*/
 
   Lcommandline = g_strdup_printf("%s -gui %s %s",
-      conf_get_string("dvd+rw-format"), Lmode, get_dvdrwtools_bus(Ldevice)); 
+      conf_get_string("dvd+rw-format"), Lmode, matos_get_device(Ldevice)); 
   _DEB("execution [%s]\n", Lcommandline);
   Lstatus = g_shell_parse_argv(Lcommandline, &Lnbrarg, &Lcmd, Aerror);
   g_free(Lcommandline);
@@ -132,6 +132,10 @@ gboolean perform_format_dvd(Tgrave *Ag, Ttypeformatdvd Aoperation, GError **Aerr
   if (Lstatus == FALSE) {
     return FALSE;
   }
+
+  /* try to umount device before device access */
+  matos_umount_device(Ldevice, NULL);
+
   Lstatus = g_spawn_async_with_pipes(NULL, Lcmd, NULL, /* env argument */
       (GSpawnFlags ) (G_SPAWN_DO_NOT_REAP_CHILD),
        NULL, NULL, Lpid, NULL, &g_out, &g_err, Aerror);
