@@ -53,7 +53,7 @@ gint get_dvdinfo(Tgrave *Ag, Tdriveinfo *Adevice, GError **Aerror)
   gint *Lpid = (gint *)sc_grave_get_data(Ag, "pid");
   GString *Loutput;
   gchar *Ldvdprg = conf_get_string("dvd+rw-mediainfo");
-  gchar *Ldevicestr = get_dvdrwtools_bus(Adevice);
+  gchar *Ldevicestr = matos_get_device(Adevice);
 
   if (!Ldvdprg || !Ldevicestr || !*Ldvdprg || !*Ldevicestr) return 0;
   
