@@ -82,7 +82,12 @@ gboolean growisofs_grave_callback(GIOChannel *Astd, GIOCondition Acond, gpointer
   }
 
   Lstatus = g_io_channel_read_line(Astd, &Lbuffer, NULL, NULL, NULL);  
-  if (!Lbuffer) return FALSE;
+  if (!Lbuffer) {
+    if (Lstatus == G_IO_STATUS_ERROR || Lstatus == G_IO_STATUS_EOF)
+      return FALSE;
+    else
+      return TRUE;
+  }
 
 _DEB("===>%s", Lbuffer);
 
@@ -123,9 +128,7 @@ _DEB("===>%s", Lbuffer);
     g_snprintf(Lsbuf2, sizeof(Lsbuf2)-1, "%.0f%%", Ltava*100);
     gtk_progress_bar_set_text(Lprogressbar, Lsbuf2);
   } else if (strstr(Lbuffer, GROWISOFS_WRITING_LEADOUT)) {
-    gboolean *Loperationstatus = (gboolean *)sc_grave_get_data(Lg, "operationstatus");
     gtk_label_set_text(Ltitle, _("Writing lead-out..."));
-    *Loperationstatus = TRUE;
   } else if ((s=strstr(Lbuffer, GROWISOFS_FAILED))) {
     gtk_label_set_text(Ltitle, _("Operation failed !"));
     s+=strlen(GROWISOFS_FAILED);
@@ -150,12 +153,11 @@ gboolean burn_data2dvd(Tgrave *Ag, GError **Aerror) {
   gint Lnbrgravure = gtk_spin_button_get_value(GTK_SPIN_BUTTON(sc_grave_get_widget(Ag, "nbrdvddata"))); 
   gint *Ldone = (gint *)sc_grave_get_data(Ag, "done"); /* fais */
 
-  gboolean *Loperationstatus = (gboolean *)sc_grave_get_data(Ag, "operationstatus");
   gboolean Lwanteject = conf_get_boolean("eject");
 
   gint *Lpid = (gint *) sc_grave_get_data(Ag, "pid");
   GtkWidget *Lvitesse = sc_grave_get_widget(Ag, "dstdvddataspeed");
-  Tdriveinfo *Ldevice = get_drive_info(Ag, "dstdvddatacombo");
+  Tdriveinfo *Ldevice = matos_get_drive_info(Ag, "dstdvddatacombo");
   GtkLabel *Ltitle = GTK_LABEL(sc_grave_get_data(Ag, "gravetitle"));
   gchar *Loperation = sc_grave_get_data(Ag, "typeburn");
   gboolean Leject = FALSE;
@@ -191,7 +193,7 @@ _DEB("nbr gravure = [%d]\n", Lnbrgravure);
       GtkWidget *Lconfirm;
       gint Lrep;
 
-      eject_cd(get_dvdrwtools_bus(Ldevice), NULL);
+      eject_cd(matos_get_device(Ldevice), NULL);
       Lstatus = waiting_for_user(*Lmediatitle1, Ag, Llmediarequis1 , &Lmediadetect1, Ldevice);
           
       if (Lstatus==FALSE) {
@@ -221,8 +223,6 @@ _DEB("nbr gravure = [%d]\n", Lnbrgravure);
      * si il faut realiser d'autre gravure sur d'autres DVD */
     Leject = ((Lcurcd > 1 && (Lwanteject || Lcurcd<Lnbrgravure)) || (Lcurcd == 1 && !Ldosimul && Lwanteject));
 
-    *Loperationstatus = FALSE;
-
     _DEB("gravure du cd [%d]", Lcurcd);
 
     Ltxt = get_title_preparing(Lnbrgravure, Lcurcd, Ldosimul);
@@ -233,7 +233,7 @@ _DEB("nbr gravure = [%d]\n", Lnbrgravure);
         conf_get_string("growisofs"), 
         Lnotfix ? "" : "-dvd-compat",
         Loperation,
-        get_dvdrwtools_bus(Ldevice),
+        matos_get_device(Ldevice),
         *Lbufvitesse != '0' ? "-speed=" : "", *Lbufvitesse != '0' ? Lbufvitesse : "",
         conf_get_boolean("overburn") ? "-overburn" : "",
         Ldosimul ? ",dummy" : "",  /* simulation ? */
@@ -293,14 +293,6 @@ _DEB("nbr gravure = [%d]\n", Lnbrgravure);
       Lstatus = FALSE;
       break;
     }
-    if (*Loperationstatus == FALSE) {
-      /* growisofs n'a pas reussi a grave le cd mais on n'a intercepte aucune erreur ! argh!
-       * dans tous les cas ce n'est pas normal, on genere une erreur */
-      g_set_error(Aerror, GRAVEMAN_ERROR, _ERR_UNKNOWN_ERROR, 
-          _("Communication error with growisofs !"));
-      Lstatus = FALSE;
-      break;
-    }
 
     if (Ldosimul) {
       /* fin de la simulation, tout s'est apparement bien passe
@@ -341,12 +333,11 @@ gboolean burn_iso2dvd(Tgrave *Ag, GError **Aerror) {
   gint Lnbrgravure = gtk_spin_button_get_value(GTK_SPIN_BUTTON(sc_grave_get_widget(Ag, "nbrdvddata"))); 
   gint *Ldone = (gint *)sc_grave_get_data(Ag, "done"); /* fais */
 
-  gboolean *Loperationstatus = (gboolean *)sc_grave_get_data(Ag, "operationstatus");
   gboolean Lwanteject = conf_get_boolean("eject");
 
   gint *Lpid = (gint *) sc_grave_get_data(Ag, "pid");
   GtkWidget *Lvitesse = sc_grave_get_widget(Ag, "dstdvddataspeed");
-  Tdriveinfo *Ldevice = get_drive_info(Ag, "dstdvddatacombo");
+  Tdriveinfo *Ldevice = matos_get_drive_info(Ag, "dstdvddatacombo");
   GtkLabel *Ltitle = GTK_LABEL(sc_grave_get_data(Ag, "gravetitle"));
   gchar *Loperation = sc_grave_get_data(Ag, "typeburn");
   gboolean Leject = FALSE;
@@ -382,7 +373,7 @@ _DEB("nbr gravure = [%d]\n", Lnbrgravure);
       GtkWidget *Lconfirm;
       gint Lrep;
 
-      eject_cd(get_dvdrwtools_bus(Ldevice), NULL);
+      eject_cd(matos_get_device(Ldevice), NULL);
       Lstatus = waiting_for_user(*Lmediatitle1, Ag, Llmediarequis1 , &Lmediadetect1, Ldevice);
           
       if (Lstatus==FALSE) {
@@ -412,8 +403,6 @@ _DEB("nbr gravure = [%d]\n", Lnbrgravure);
      * si il faut realiser d'autre gravure sur d'autres DVD */
     Leject = ((Lcurcd > 1 && (Lwanteject || Lcurcd<Lnbrgravure)) || (Lcurcd == 1 && !Ldosimul && Lwanteject));
 
-    *Loperationstatus = FALSE;
-
     _DEB("gravure du cd [%d]", Lcurcd);
 
     Ltxt = get_title_preparing(Lnbrgravure, Lcurcd, Ldosimul);
@@ -424,7 +413,7 @@ _DEB("nbr gravure = [%d]\n", Lnbrgravure);
         conf_get_string("growisofs"), 
         Lnotfix ? "" : "-dvd-compat",
         Loperation,
-        get_dvdrwtools_bus(Ldevice),
+        matos_get_device(Ldevice),
         *Lbufvitesse != '0' ? "-speed=" : "", *Lbufvitesse != '0' ? Lbufvitesse : "",
         conf_get_boolean("overburn") ? "-overburn" : "",
         Ldosimul ? ",dummy" : "",  /* simulation ? */
@@ -440,6 +429,9 @@ _DEB("nbr gravure = [%d]\n", Lnbrgravure);
       break;
     }
 
+    /* try to umount device before device access */
+    matos_umount_device(Ldevice, NULL);
+
     Lstatus = g_spawn_async_with_pipes(NULL, Lcmd, NULL, /* env argument */
         (GSpawnFlags ) (G_SPAWN_DO_NOT_REAP_CHILD),
         NULL, NULL, Lpid, NULL, &g_out, &g_err, Aerror);
@@ -484,14 +476,6 @@ _DEB("nbr gravure = [%d]\n", Lnbrgravure);
       Lstatus = FALSE;
       break;
     }
-    if (*Loperationstatus == FALSE) {
-      /* growisofs n'a pas reussi a grave le cd mais on n'a intercepte aucune erreur ! argh!
-       * dans tous les cas ce n'est pas normal, on genere une erreur */
-      g_set_error(Aerror, GRAVEMAN_ERROR, _ERR_UNKNOWN_ERROR, 
-          _("Communication error with growisofs !"));
-      Lstatus = FALSE;
-      break;
-    }
 
     if (Ldosimul) {
       /* fin de la simulation, tout s'est apparement bien passe
