@@ -188,6 +188,22 @@ void free_all_images()
 */
 }
 
+/* load dynamic image used by main window */
+gboolean image_prepare_main_window(Tgrave *Ag)
+{
+  gtk_image_set_from_pixbuf(GTK_IMAGE(sc_grave_get_widget(Ag, "imgburnaudio2")), get_image("BurnsmallIcon"));
+  gtk_image_set_from_pixbuf(GTK_IMAGE(sc_grave_get_widget(Ag, "imgburndata2")), get_image("BurnsmallIcon"));
+  gtk_image_set_from_pixbuf(GTK_IMAGE(sc_grave_get_widget(Ag, "imgburndata3")), get_image("BurnsmallIcon"));
+  gtk_image_set_from_pixbuf(GTK_IMAGE(sc_grave_get_widget(Ag, "imgburncopy1")), get_image("BurnsmallIcon"));
+  gtk_image_set_from_pixbuf(GTK_IMAGE(sc_grave_get_widget(Ag, "imgfixcdother1")), get_image("BurnsmallIcon"));
+  gtk_image_set_from_pixbuf(GTK_IMAGE(sc_grave_get_widget(Ag, "imgburndvddata2")), get_image("BurnsmallIcon"));
+  gtk_image_set_from_pixbuf(GTK_IMAGE(sc_grave_get_widget(Ag, "imgburndvddata3")), get_image("BurnsmallIcon"));
+  gtk_image_set_from_pixbuf(GTK_IMAGE(sc_grave_get_widget(Ag, "imgerasecdrwother1")), get_image("EraseCDRWIcon"));
+  gtk_image_set_from_pixbuf(GTK_IMAGE(sc_grave_get_widget(Ag, "imgformatdvdrwother1")), get_image("EraseCDRWIcon"));
+
+  return TRUE;
+}
+
 /*
  * vim:et:ts=8:sts=2:sw=2
  */
