@@ -38,17 +38,6 @@ GtkTargetEntry Gdnddata[] = { {"text/uri-list", 0, TARGET_URI_LIST } };
 /* liste des medias */
 GSList *Gmedialist = NULL;
 
-#if 0
-Tmediaentry Gdefaultmedia[] = {
-  { 665600, N_("74 min"), N_("650 mb") },
-  { 716800, N_("80 min"), N_("700 mb") },
-  { 808960, N_("90 min"), N_("790 mb") },
-  { 889856, N_("99 min"), N_("869 mb") },
-  { 899072, N_("100 min"), N_("878 mb") },
-  { 0, "", "" },
-};
-#endif
-
 static Tmyentry Gtypecdaudio[] = {
   { "1260", N_("21 min"), FALSE, 0 },
   { "1380", N_("23 min"), FALSE, 0 },
@@ -406,7 +395,8 @@ GtkMenu *create_gtkpopupmenudata(GtkWidget *Aliste, Tgrave *Ag)
   GtkWidget *Litem, *Litem2, *Lsep;
   GtkTreeSelection *Lselection = gtk_tree_view_get_selection(GTK_TREE_VIEW(Aliste));
   GtkTreeIter Liter;
-  gint type;
+  gint type, Lcolid = 0;
+  GtkSortType Lorder;
   gint Lnumsel = gtk_tree_selection_count_selected_rows(Lselection);
   gboolean Lonlyone = TRUE;
   const gchar *Llistename = glade_get_widget_name(Aliste);
@@ -508,11 +498,7 @@ GtkMenu *create_gtkpopupmenudata(GtkWidget *Aliste, Tgrave *Ag)
   Lsep = sc_grave_get_widget(Ag, "popupdata_sep2");
   Litem = sc_grave_get_widget(Ag, "popupdata_remove");
   if (type != TYPE_CD) {
-    if (Lonlyone) {
-      gtk_widget_show (Lsep);
-    } else {
-      gtk_widget_hide (Lsep);
-    }
+    gtk_widget_hide (Lsep);
     gtk_widget_set_sensitive(Litem, TRUE);
     gtk_widget_show (Litem);
 
@@ -543,6 +529,19 @@ GtkMenu *create_gtkpopupmenudata(GtkWidget *Aliste, Tgrave *Ag)
     gtk_widget_hide (Litem);
   }*/
 
+  /* TRIER */
+  if (!gtk_tree_sortable_get_sort_column_id(GTK_TREE_SORTABLE(Lmodel), &Lcolid, &Lorder)) Lcolid=0;
+
+  if (Lcolid == 2) { 
+    gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(sc_grave_get_widget(Ag, "popupdata_sort_name")), TRUE); 
+  } else if (Lcolid == 3) {
+    gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(sc_grave_get_widget(Ag, "popupdata_sort_size")), TRUE); 
+  } else if (Lcolid == 4) {
+    gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(sc_grave_get_widget(Ag, "popupdata_sort_location")), TRUE); 
+  } else {
+    gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(sc_grave_get_widget(Ag, "popupdata_sort_none")), TRUE); 
+  }
+
   return Lmenu;
 }
 
@@ -550,69 +549,76 @@ void prepare_popups(Tgrave *Ag)
 {
   /* popup cd audio */
   g_signal_connect(G_OBJECT(sc_grave_get_widget(Ag, "popupaudio_addtrack")),
-      "activate", G_CALLBACK(gtk_audio_addtrack), Ag);
+    "activate", G_CALLBACK(gtk_audio_addtrack), Ag);
   g_signal_connect(G_OBJECT(sc_grave_get_widget(Ag, "popupaudio_removetrack")),
-      "activate", G_CALLBACK(gtk_audio_removetrack), Ag);
+    "activate", G_CALLBACK(gtk_audio_removetrack), Ag);
   g_signal_connect(G_OBJECT(sc_grave_get_widget(Ag, "popupaudio_append")),
-      "activate", G_CALLBACK(menu_load), Ag);
+    "activate", G_CALLBACK(menu_load), Ag);
 
   /* popup cd data */
   g_signal_connect(G_OBJECT(sc_grave_get_widget(Ag, "popupdata_renamecd")),
-      "activate", G_CALLBACK(gtk_data_renommerelement), Ag);
+    "activate", G_CALLBACK(callbacks_data_renameitem), Ag);
   g_signal_connect(G_OBJECT(sc_grave_get_widget(Ag, "popupdata_renamedvd")),
-      "activate", G_CALLBACK(gtk_data_renommerelement), Ag);
+    "activate", G_CALLBACK(callbacks_data_renameitem), Ag);
 
   g_signal_connect(G_OBJECT(sc_grave_get_widget(Ag, "popupdata_expand")),
-      "activate", G_CALLBACK(gtk_data_expandelement), Ag);
+    "activate", G_CALLBACK(gtk_data_expandelement), Ag);
   g_signal_connect(G_OBJECT(sc_grave_get_widget(Ag, "popupdata_renamefile")),
-      "activate", G_CALLBACK(gtk_data_renommerelement), Ag);
+    "activate", G_CALLBACK(callbacks_data_renameitem), Ag);
   g_signal_connect(G_OBJECT(sc_grave_get_widget(Ag, "popupdata_renamedirectory")),
-      "activate", G_CALLBACK(gtk_data_renommerelement), Ag);
+    "activate", G_CALLBACK(callbacks_data_renameitem), Ag);
   g_signal_connect(G_OBJECT(sc_grave_get_widget(Ag, "popupdata_createdirectory")),
-      "activate", G_CALLBACK(gtk_data_creerrepertoire), Ag);
-  sc_grave_get_widget(Ag, "popupdata_sep1");
+    "activate", G_CALLBACK(gtk_data_creerrepertoire), Ag);
   g_signal_connect(G_OBJECT(sc_grave_get_widget(Ag, "popupdata_addfile")),
-      "activate", G_CALLBACK(gtk_data_addfile), Ag);
+    "activate", G_CALLBACK(gtk_data_addfile), Ag);
   g_signal_connect(G_OBJECT(sc_grave_get_widget(Ag, "popupdata_adddirectory")),
-      "activate", G_CALLBACK(gtk_data_adddirectory), Ag);
+    "activate", G_CALLBACK(gtk_data_adddirectory), Ag);
 
-  sc_grave_get_widget(Ag, "popupdata_sep2");
   g_signal_connect(G_OBJECT(sc_grave_get_widget(Ag, "popupdata_remove")),
-      "activate", G_CALLBACK(gtk_data_removefiles), Ag);
+    "activate", G_CALLBACK(gtk_data_removefiles), Ag);
+
+  /* tris */
+  g_signal_connect(G_OBJECT(sc_grave_get_widget(Ag, "popupdata_sort_none")),
+    "activate", G_CALLBACK(callbacks_data_asksort), Ag);
+  g_signal_connect(G_OBJECT(sc_grave_get_widget(Ag, "popupdata_sort_name")),
+    "activate", G_CALLBACK(callbacks_data_asksort), Ag);
+  g_signal_connect(G_OBJECT(sc_grave_get_widget(Ag, "popupdata_sort_size")),
+    "activate", G_CALLBACK(callbacks_data_asksort), Ag);
+
 
 #if 0
-  sc_grave_get_widget(Ag, "popupdata_sep3");
-  g_signal_connect(G_OBJECT(sc_grave_get_widget(Ag, "popupdata_imageboot")),
-      "activate", G_CALLBACK(gtk_def_imageboot), Ahash);
+sc_grave_get_widget(Ag, "popupdata_sep3");
+g_signal_connect(G_OBJECT(sc_grave_get_widget(Ag, "popupdata_imageboot")),
+    "activate", G_CALLBACK(gtk_def_imageboot), Ahash);
 #endif
 
-  /* popup affichage */
+/* popup affichage */
   g_signal_connect(G_OBJECT(sc_grave_get_widget(Ag, "popupdisp_iconsize_48")),
-      "activate", G_CALLBACK(gtk_display_updatesize), Ag);
+    "activate", G_CALLBACK(gtk_display_updatesize), Ag);
   g_signal_connect(G_OBJECT(sc_grave_get_widget(Ag, "popupdisp_iconsize_32")),
-      "activate", G_CALLBACK(gtk_display_updatesize), Ag);
+    "activate", G_CALLBACK(gtk_display_updatesize), Ag);
   g_signal_connect(G_OBJECT(sc_grave_get_widget(Ag, "popupdisp_iconsize_24")),
-      "activate", G_CALLBACK(gtk_display_updatesize), Ag);
+    "activate", G_CALLBACK(gtk_display_updatesize), Ag);
   g_signal_connect(G_OBJECT(sc_grave_get_widget(Ag, "popupdisp_iconsize_16")),
-      "activate", G_CALLBACK(gtk_display_updatesize), Ag);
+    "activate", G_CALLBACK(gtk_display_updatesize), Ag);
 
   g_signal_connect(G_OBJECT(sc_grave_get_widget(Ag, "popupdisp_showstatusbar")),
-      "activate", G_CALLBACK(gtk_display_switchstatusbar), Ag);
+    "activate", G_CALLBACK(gtk_display_switchstatusbar), Ag);
   g_signal_connect(G_OBJECT(sc_grave_get_widget(Ag, "popupdisp_hidestatusbar")),
       "activate", G_CALLBACK(gtk_display_switchstatusbar), Ag);
 
   /* popup formater un dvd */
   g_signal_connect(G_OBJECT(sc_grave_get_widget(Ag, "popupform_format")),
-      "activate", G_CALLBACK(gtk_confirm_dvdoperation), Ag);
+    "activate", G_CALLBACK(gtk_confirm_dvdoperation), Ag);
   g_signal_connect(G_OBJECT(sc_grave_get_widget(Ag, "popupform_blank")),
-      "activate", G_CALLBACK(gtk_confirm_dvdoperation), Ag);
+    "activate", G_CALLBACK(gtk_confirm_dvdoperation), Ag);
   g_signal_connect(G_OBJECT(sc_grave_get_widget(Ag, "popupform_blankfull")),
-      "activate", G_CALLBACK(gtk_confirm_dvdoperation), Ag);
+    "activate", G_CALLBACK(gtk_confirm_dvdoperation), Ag);
 }
 
 /* fenetre principal */
 Tgrave *manage_main_window (guint64 *Aaudiolen, guint64 *Aaudiomaxlen,
-    guint64 *Adatasize, guint64 *Adatamaxsize, guint64 *Advddatasize, guint64 *Advddatamaxsize)
+  guint64 *Adatasize, guint64 *Adatamaxsize, guint64 *Advddatasize, guint64 *Advddatamaxsize)
 {
   Tgrave *Lg = sc_grave_load("window_main.glade");
   GtkWidget *Lwindow;
@@ -627,6 +633,7 @@ Tgrave *manage_main_window (guint64 *Aaudiolen, guint64 *Aaudiomaxlen,
   Lwindow = GTK_WIDGET(sc_grave_get_widget(Lg, "topwindow"));
 
   sc_tooltips(Lwindow, conf_get_boolean("tooltips"));
+  image_prepare_main_window(Lg);
 
   sc_grave_set_data(Lg, Lwindow, "window");
   sc_grave_set_data(Lg, Aaudiolen, "audiolen");
@@ -648,28 +655,28 @@ Tgrave *manage_main_window (guint64 *Aaudiolen, guint64 *Aaudiomaxlen,
   Lbodycdother = GTK_NOTEBOOK(sc_grave_get_widget(Lg, "bodycdother"));
   gtk_widget_reparent(GTK_WIDGET(Lbodycdother), GTK_WIDGET(Lmainbody));
   sc_grave_replace_data(Lg, Lbodycdaudio, "_lstclicked");
-
+  
   /* mise a jour des label lorsque l'on change d'onglet dans la partie "graver un cd de donnee" */
   g_signal_connect(G_OBJECT(Lbodycddata), "switch-page", G_CALLBACK(switchpage), Lg);
   /* mise a jour des label lorsque l'on change d'onglet dans la partie "graver un dvd de donnee" */
   g_signal_connect(G_OBJECT(Lbodydvddata), "switch-page", G_CALLBACK(switchpage), Lg);
-
+  
   /* bouttons barre de gauche */
   Ltopmenu = GTK_TREE_VIEW(sc_grave_get_widget(Lg, "topmenu"));
-
+  
   manage_interface(Lg, MENU_NEW + COMBO_UPDATE);
   update_status_bar_display(Lg);
-
+  
   g_signal_connect(G_OBJECT(Ltopmenu), "button-press-event", G_CALLBACK(gtk_do_eventbuttonpress), Lg);
   g_signal_connect(G_OBJECT(Ltopmenu), "popup-menu", G_CALLBACK(key_popupmenu_display), Lg);
-
-
+  
+  
   /* signaux sur le menu */
   g_signal_connect(G_OBJECT(sc_grave_get_widget(Lg, "menustartnew")), "activate",
       G_CALLBACK(menu_start_new), Lg);
   g_signal_connect(G_OBJECT(sc_grave_get_widget(Lg, "menuload")), "activate",
       G_CALLBACK(menu_load), Lg);
-
+  
   g_signal_connect(G_OBJECT(sc_grave_get_widget(Lg, "menucdaudio")), "activate",
       G_CALLBACK(menu_active_panel), Lg);
   g_signal_connect(G_OBJECT(sc_grave_get_widget(Lg, "menucddata")), "activate",
@@ -691,27 +698,27 @@ Tgrave *manage_main_window (guint64 *Aaudiolen, guint64 *Aaudiomaxlen,
   prepare_combobox_vitesse(GTK_COMBO_BOX(sc_grave_get_widget(Lg, "dstcopyspeed")));
   prepare_combobox_vitesse(GTK_COMBO_BOX(sc_grave_get_widget(Lg, "dstdataspeed")));
   prepare_combobox_vitesse(GTK_COMBO_BOX(sc_grave_get_widget(Lg, "dstdvddataspeed")));
-
+  
   /* tous les combo contenant la liste des lecteurs */
   prepare_combobox_graveur(Lg, "dstaudio");
   
   prepare_combobox_graveur(Lg, "dstdata");
   prepare_disable_when_iso(Lg, "dstdatacombo", "nbrcddata", "datamulti", "datanotfix", "datasimul", NULL);
-
+  
   prepare_combobox_graveur(Lg, "dstdvddata");
   prepare_disable_when_iso(Lg, "dstdvddatacombo", "nbrdvddata", "dvddatanotfix", "dvddatasimul", NULL);
-
+  
   prepare_combobox_graveur(Lg, "srccopy");
   prepare_combobox_graveur(Lg, "dstcopy");
-
+  
   prepare_combobox_graveur(Lg, "dstother");
   prepare_disable_when(Lg, "dstothercombo_notcdrw", "btnerasecdrwother1", NULL);
   prepare_disable_when(Lg, "dstothercombo_notdvdrw", "btnformatdvdrwother1", NULL);
-
+  
   /* checkbox continuer un cd multi session, on ne permet dans ce cas pas de faire
    * plusieurs copie a la suite */
   g_signal_connect(G_OBJECT(sc_grave_get_widget(Lg, "datamulti")), "toggled", G_CALLBACK(change_datamulti), Lg);
-
+  
   
   /* on rempli les autres combo */
   remplirecombo(GTK_COMBO_BOX(sc_grave_get_widget(Lg, "dataformat")), "", Gformatcd,
@@ -721,22 +728,22 @@ Tgrave *manage_main_window (guint64 *Aaudiolen, guint64 *Aaudiomaxlen,
   Lcombo = GTK_COMBO_BOX(sc_grave_get_widget(Lg, "listeremplidata"));
   remplirecombo(Lcombo, "", Gtypecddata, TRUE, conf_get_string("listeremplidata")); 
   g_signal_connect(G_OBJECT(Lcombo), "changed", G_CALLBACK(change_remplissage), Lg);
-
+  
   Lcombo = GTK_COMBO_BOX(sc_grave_get_widget(Lg, "listeremplidvddata"));
   remplirecombo(Lcombo, "", Gtypedvddata, TRUE, conf_get_string("listeremplidvddata")); 
   g_signal_connect(G_OBJECT(Lcombo), "changed", G_CALLBACK(change_remplissage), Lg);
-
+  
   Lcombo = GTK_COMBO_BOX(sc_grave_get_widget(Lg, "listerempliaudio"));
   remplirecombo(Lcombo, "", Gtypecdaudio, TRUE, conf_get_string("listerempliaudio"));
   g_signal_connect(G_OBJECT(Lcombo), "changed", G_CALLBACK(change_remplissage), Lg);
- 
+  
   /* boutons "page suivante" */
   g_signal_connect(G_OBJECT(sc_grave_get_widget(Lg, "btnnextaudio1")), "clicked", G_CALLBACK(gonextpage), Lbodycdaudio);
   g_signal_connect(G_OBJECT(sc_grave_get_widget(Lg, "btnnextdata1")), "clicked", G_CALLBACK(gonextpage), Lbodycddata);
   g_signal_connect(G_OBJECT(sc_grave_get_widget(Lg, "btnnextdata2")), "clicked", G_CALLBACK(gonextpage), Lbodycddata);
   g_signal_connect(G_OBJECT(sc_grave_get_widget(Lg, "btnnextdvddata1")), "clicked", G_CALLBACK(gonextpage), Lbodydvddata);
   g_signal_connect(G_OBJECT(sc_grave_get_widget(Lg, "btnnextdvddata2")), "clicked", G_CALLBACK(gonextpage), Lbodydvddata);
-
+  
   /* boutons "graver" */
   g_signal_connect(G_OBJECT(sc_grave_get_widget(Lg, "btnburnaudio2")), "clicked", G_CALLBACK(confirm_burn), Lg);
   g_signal_connect(G_OBJECT(sc_grave_get_widget(Lg, "btnburndata2")), "clicked", G_CALLBACK(confirm_burn), Lg);
@@ -744,14 +751,14 @@ Tgrave *manage_main_window (guint64 *Aaudiolen, guint64 *Aaudiomaxlen,
   g_signal_connect(G_OBJECT(sc_grave_get_widget(Lg, "btnburndvddata2")), "clicked", G_CALLBACK(confirm_burn), Lg);
   g_signal_connect(G_OBJECT(sc_grave_get_widget(Lg, "btnburndvddata3")), "clicked", G_CALLBACK(confirm_burn), Lg);
   g_signal_connect(G_OBJECT(sc_grave_get_widget(Lg, "btnburncopy1")), "clicked", G_CALLBACK(confirm_burn), Lg);
-
+  
   /* boutons de la page "autres operations" */
   g_signal_connect(G_OBJECT(sc_grave_get_widget(Lg, "btnerasecdrwother1")), "clicked", G_CALLBACK(confirm_erasecdrw), Lg);
   g_signal_connect(G_OBJECT(sc_grave_get_widget(Lg, "btnformatdvdrwother1")), "clicked", G_CALLBACK(popup_formatdvdrw), Lg);
   g_signal_connect(G_OBJECT(sc_grave_get_widget(Lg, "btnfixcdother1")), "clicked", G_CALLBACK(confirm_fixcd), Lg);
   
   update_combo_graveur(Lg);
-
+  
   /* menu popup sur les listes */
   Ltreeaudio = GTK_TREE_VIEW(sc_grave_get_widget(Lg, "LISTEAUDIO"));
 
@@ -833,8 +840,7 @@ void update_combo_graveur(Tgrave *Ag)
   GtkButton *Lbtnfixcdother1 = GTK_BUTTON(sc_grave_get_widget(Ag, "btnfixcdother1"));
   GtkButton *Lbtnerasecdrwother1 = GTK_BUTTON(sc_grave_get_widget(Ag, "btnerasecdrwother1"));
   gboolean Lreadcd, Lwritecdr, Lwritecdrw, Lreaddvd, Lwritedvd;
-
-  get_current_matos(&Lreadcd, &Lwritecdr, &Lwritecdrw, &Lreaddvd, &Lwritedvd);
+  matos_get_current_matos(&Lreadcd, &Lwritecdr, &Lwritecdrw, &Lreaddvd, &Lwritedvd);
   
   remplirecombograveur(Lsrccopycombo, TYPE_ALL + TYPE_ISO, conf_get_string("srccopycombo"));
   
@@ -848,16 +854,10 @@ void update_combo_graveur(Tgrave *Ag)
 
   remplirecombograveur(Ldstothercombo, TYPE_ALLWRITER, conf_get_string("dstothercombo"));
 
-  if (Lreadcd == FALSE) {
-    gtk_widget_set_sensitive(GTK_WIDGET(Lbtnburncopy1), FALSE);
-  }
-  if (Lwritecdr == FALSE) {
-    gtk_widget_set_sensitive(GTK_WIDGET(Lbtnburnaudio2), FALSE);
-    gtk_widget_set_sensitive(GTK_WIDGET(Lbtnfixcdother1), FALSE);
-  }
-  if (Lwritecdrw == FALSE) {
-    gtk_widget_set_sensitive(GTK_WIDGET(Lbtnerasecdrwother1), FALSE);
-  }
+  gtk_widget_set_sensitive(GTK_WIDGET(Lbtnburncopy1), Lreadcd);
+  gtk_widget_set_sensitive(GTK_WIDGET(Lbtnburnaudio2), Lwritecdr);
+  gtk_widget_set_sensitive(GTK_WIDGET(Lbtnfixcdother1), Lwritecdr);
+  gtk_widget_set_sensitive(GTK_WIDGET(Lbtnerasecdrwother1), Lwritecdrw);
 /*if (Lwritedvd == FALSE) { et l'image iso ?! 
     gtk_widget_set_sensitive(GTK_WIDGET(Lbtnburndvddata2), FALSE);
     gtk_widget_set_sensitive(GTK_WIDGET(Lbtnburndvddata3), FALSE);
@@ -1065,6 +1065,7 @@ Tgrave *create_dialog_edit_device(GtkWidget *Aparent, Tdriveinfo *Adrive)
   Ldialog = sc_grave_get_widget(Lg, "dialog_device");
   gtk_window_set_transient_for(GTK_WINDOW(Ldialog), GTK_WINDOW(Aparent));
   sc_grave_ref_wtd(Lg, "dialog_device", "window");
+  gtk_dialog_set_default_response(GTK_DIALOG(Ldialog), GTK_RESPONSE_OK);
 
   gtk_entry_set_text(GTK_ENTRY(sc_grave_get_widget(Lg, "devicename")), Adrive->name);
   Lcombobox = GTK_COMBO_BOX(sc_grave_get_widget(Lg, "devicebus"));
@@ -1086,6 +1087,8 @@ Tgrave *create_dialog_add_device(GtkWidget *Aparent)
   gtk_window_set_transient_for(GTK_WINDOW(Ldialog), GTK_WINDOW(Aparent));
   sc_grave_ref_wtd(Lg, "dialog_add_device", "window");
 
+  gtk_dialog_set_default_response(GTK_DIALOG(Ldialog), GTK_RESPONSE_OK);
+
   gtk_entry_set_text(GTK_ENTRY(sc_grave_get_widget(Lg, "devicename")), _("New device"));
 
   return Lg;
@@ -1154,12 +1157,11 @@ void show_graverwindow (Tgrave *Ag, gchar *Aaction, gchar *Atitle)
 
   /* on insere le logo anim mng */
 
-  gtk_mng_free(Lmnglogo);
   gtk_table_attach(GTK_TABLE(sc_grave_get_widget(Lburng, "tableburn")),
                    GTK_WIDGET(Lmngview), 0, 1, 0, 1, GTK_FILL, GTK_FILL, 0, 0);
   gtk_mng_view_load(Lmngview, Lmnglogo);
   gtk_widget_show(GTK_WIDGET(Lmngview));
-
+  gtk_mng_free(Lmnglogo);
 
   /* barres de progression */
   Lpbtotal = GTK_PROGRESS_BAR(sc_grave_get_widget(Lburng, "pb_total"));
@@ -1256,6 +1258,8 @@ Tgrave *create_window_encours(GtkWidget *Aparent)
 
   g_assert(Lg);
 
+  gtk_image_set_from_pixbuf(GTK_IMAGE(sc_grave_get_widget(Lg, "imgburning")), get_image("BurnIcon"));
+
   if (GTK_IS_WIDGET(Aparent)) {
     gtk_window_set_transient_for(GTK_WINDOW(sc_grave_get_widget(Lg, "window_inprogress")), GTK_WINDOW(Aparent));
   }
@@ -1348,6 +1352,8 @@ void gtk_toggle_top_menu(GtkTreeView *Atopmenu, gpointer Adata)
       sc_grave_replace_data(Lg, sc_grave_get_widget(Lg, "LISTEDATA"), "_current_list");
     } else if (!strcmp(Lident, "bodydvddata")) {
       sc_grave_replace_data(Lg, sc_grave_get_widget(Lg, "LISTEDVDDATA"), "_current_list");
+    } else if (!strcmp(Lident, "bodycdaudio")) {
+      sc_grave_replace_data(Lg, sc_grave_get_widget(Lg, "LISTEAUDIO"), "_current_list");
     }
   }
   g_free(Lident);
@@ -1510,18 +1516,22 @@ void prepare_properties_devicestreeview(GtkTreeView *Atreeview)
   /* creation colonnes */
   Lcellrender = gtk_cell_renderer_pixbuf_new();
   Lcell = gtk_tree_view_column_new_with_attributes("", Lcellrender, "pixbuf", 1, NULL);
+  gtk_tree_view_column_set_resizable(Lcell, TRUE);
   gtk_tree_view_append_column(GTK_TREE_VIEW(Atreeview), Lcell);
 
   Lcellrender = gtk_cell_renderer_text_new();
   Lcell = gtk_tree_view_column_new_with_attributes(_("Location"), Lcellrender, "text", 2, NULL);
+  gtk_tree_view_column_set_resizable(Lcell, TRUE);
   gtk_tree_view_append_column(GTK_TREE_VIEW(Atreeview), Lcell);
 
   Lcellrender = gtk_cell_renderer_text_new();
   Lcell = gtk_tree_view_column_new_with_attributes(_("Type"), Lcellrender, "text", 3, NULL);
+  gtk_tree_view_column_set_resizable(Lcell, TRUE);
   gtk_tree_view_append_column(GTK_TREE_VIEW(Atreeview), Lcell);
 
   Lcellrender = gtk_cell_renderer_text_new();
   Lcell = gtk_tree_view_column_new_with_attributes(_("Name"), Lcellrender, "text", 4, NULL);
+  gtk_tree_view_column_set_resizable(Lcell, TRUE);
   gtk_tree_view_append_column(GTK_TREE_VIEW(Atreeview), Lcell);
 
 }
@@ -1539,18 +1549,24 @@ void prepare_listeaudio(GtkTreeView *Atreeaudio)
   /* creation colonnes */
   Lcellrender = gtk_cell_renderer_pixbuf_new();
   Lcell = gtk_tree_view_column_new_with_attributes("", Lcellrender, "pixbuf", 1, NULL);
+  gtk_tree_view_column_set_resizable(Lcell, TRUE);
   gtk_tree_view_append_column(GTK_TREE_VIEW(Atreeaudio), Lcell);
 	
   Lcellrender = gtk_cell_renderer_text_new();
   Lcell = gtk_tree_view_column_new_with_attributes(_("Track"), Lcellrender, "text", 2, NULL);
+  gtk_tree_view_column_set_resizable(Lcell, TRUE);
+  gtk_tree_view_column_set_sort_column_id (Lcell, 2);
   gtk_tree_view_append_column(GTK_TREE_VIEW(Atreeaudio), Lcell);
 
   Lcellrender = gtk_cell_renderer_text_new();
   Lcell = gtk_tree_view_column_new_with_attributes(_("Length"), Lcellrender, "text", 3, NULL);
+  gtk_tree_view_column_set_resizable(Lcell, TRUE);
+  gtk_tree_view_column_set_sort_column_id (Lcell, 3);
   gtk_tree_view_append_column(GTK_TREE_VIEW(Atreeaudio), Lcell);
 
   Lcellrender = gtk_cell_renderer_text_new();
   Lcell = gtk_tree_view_column_new_with_attributes(_("Location"), Lcellrender, "text", 4, NULL);
+  gtk_tree_view_column_set_sort_column_id (Lcell, 4);
   gtk_tree_view_append_column(GTK_TREE_VIEW(Atreeaudio), Lcell);
 
   gtk_tree_view_set_model(Atreeaudio, GTK_TREE_MODEL(Lmodel));
@@ -1565,6 +1581,8 @@ void prepare_listedata(GtkTreeView *Atreedata, gchar *Atitle)
   GtkCellRenderer *Lcellrender;
   GtkTreeViewColumn *Lcell;
 
+//  gtk_tree_sortable_set_default_sort_func(GTK_TREE_SORTABLE(Lmodel), GTK_TREE_SORTABLE_DEFAULT_SORT_COLUMN_ID, NULL, NULL);
+
   gtk_tree_selection_set_mode(Lselection, GTK_SELECTION_MULTIPLE);
   gtk_tree_view_set_enable_search(Atreedata, TRUE);
   gtk_tree_view_set_model(Atreedata, GTK_TREE_MODEL(Lmodel));
@@ -1572,18 +1590,25 @@ void prepare_listedata(GtkTreeView *Atreedata, gchar *Atitle)
   /* creation colonnes */
   Lcellrender = gtk_cell_renderer_pixbuf_new();
   Lcell = gtk_tree_view_column_new_with_attributes("", Lcellrender, "pixbuf", 1, NULL);
+  gtk_tree_view_column_set_resizable(Lcell, TRUE);
   gtk_tree_view_append_column(Atreedata, Lcell);
-	
+  
   Lcellrender = gtk_cell_renderer_text_new();
   Lcell = gtk_tree_view_column_new_with_attributes(_("Name"), Lcellrender, "text", 2, NULL);
+  
+  gtk_tree_view_column_set_sort_column_id (Lcell, 2);
+  gtk_tree_view_column_set_resizable(Lcell, TRUE);
   gtk_tree_view_append_column(Atreedata, Lcell);
 
   Lcellrender = gtk_cell_renderer_text_new();
   Lcell = gtk_tree_view_column_new_with_attributes(_("Size"), Lcellrender, "text", 3, NULL);
+  gtk_tree_view_column_set_sort_column_id (Lcell, 3);
+  gtk_tree_view_column_set_resizable(Lcell, TRUE);
   gtk_tree_view_append_column(Atreedata, Lcell);
 
   Lcellrender = gtk_cell_renderer_text_new();
   Lcell = gtk_tree_view_column_new_with_attributes(_("Location"), Lcellrender, "text", 4, NULL);
+  gtk_tree_view_column_set_sort_column_id (Lcell, 4);
   gtk_tree_view_append_column(Atreedata, Lcell);
 
   /* icone de base dans la liste des fichiers */
@@ -1853,6 +1878,23 @@ void show_dvdformatwindow(Tgrave *Ag, gchar *Atitle, Ttypeformatdvd Aoperation)
   if (Lerror) g_error_free(Lerror);
 }
 
+/* expand or callapse GtkTreeView */
+gboolean expand_list_icons(GtkTreeView *Aliste, gboolean Aetat)
+{
+  GtkTreePath *Lpath = NULL;
+
+  gtk_tree_view_get_cursor(Aliste, &Lpath, NULL);
+  if (!Lpath) return FALSE;
+
+  if (Aetat) {
+    gtk_tree_view_expand_row(Aliste, Lpath, TRUE);
+  } else {
+    gtk_tree_view_collapse_row(Aliste, Lpath);
+  }
+  gtk_tree_path_free(Lpath);
+
+  return TRUE;
+}
 /*
  * vim:et:ts=8:sts=2:sw=2
  */
