@@ -24,20 +24,7 @@
 
 #include "graveman.h"
 
-GladeXML *Gxml = NULL;
-
-
-gboolean graveman_glade_init(gchar *Afilename) {
-  if (!Gxml) {
-    if (!(Gxml = glade_xml_new(Afilename,NULL,NULL))) {
-      g_warning("Error init glade !\n");
-      return FALSE;
-    }
-
-    glade_xml_signal_autoconnect(Gxml);
-  }
-  return TRUE;
-}
+gchar *Glocale = NULL;
 
 /* programme principal ! */
 gint main (gint Aargc, gchar *Aargv[])
@@ -47,28 +34,34 @@ gint main (gint Aargc, gchar *Aargv[])
   guint64 Laudiomaxlen = 4800;  /* par defaut, cd audio de 80 minutes */
   guint64 Ldatamaxsize = 700 * 1024 * 1024; /* par defaut, cd de donnee de 700 Mb */
   guint64 Ldvddatamaxsize = G_GINT64_CONSTANT(4700000000); /* pas default, dvd de donnee de 4.7 Gb */
+  gchar *Lcurdomain = NULL;
 
 #ifdef ENABLE_NLS
   bindtextdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR);
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
-  textdomain (GETTEXT_PACKAGE);
+  Lcurdomain = textdomain (GETTEXT_PACKAGE);
+  gtk_disable_setlocale();
 #endif
   gtk_init (&Aargc, &Aargv);
+#ifdef ENABLE_NLS
+  Glocale = gtk_set_locale();
+#endif
 
   if (!graveman_init(Aargc, Aargv)) return EXIT_SUCCESS;
 
-  add_pixmap_directory (PACKAGE_DATA_DIR "/" PACKAGE );
-
   /* on regarde si il y a un fichier de configuration present, si non on en
    * genere un nouveau */
   config_init();
   if (get_config_file(R_OK) == FALSE) {
     Tgrave *Lg = sc_grave_newempty();
-    manage_config(Lg, SEARCH_LECTEUR + CONF_INIT_DEFAULT + SEARCH_PROG + SEARCH_CHARSETS + WRITE_CONFIG, &Lerror);
+    load_all_images();
+    manage_config(Lg, SEARCH_LECTEUR + CONF_INIT_DEFAULT + SEARCH_PROG + SEARCH_CHARSETS +
+                      WRITE_CONFIG, &Lerror);
     sc_grave_destroy(Lg);
     welcome_to_graveman();
   } else {
     if (read_config(&Lerror)==FALSE) return EXIT_FAILURE;
+    load_all_images();
     if (conf_get_boolean("scan_drives") || param_get_boolean("scan_drives"))
     {
       Tgrave *Lg = sc_grave_newempty();
@@ -77,8 +70,10 @@ gint main (gint Aargc, gchar *Aargv[])
       sc_grave_destroy(Lg);
     }
   }
-
-  load_all_images();
+  
+  if (Lerror) {
+    g_warning("%s", Lerror->message);
+  }
   
   manage_main_window (&Laudiolen, &Laudiomaxlen, &Ldatasize, &Ldatamaxsize, &Ldvdsize, &Ldvddatamaxsize); 
 
