@@ -96,7 +96,7 @@ void free_drives(gboolean Aremovemanu)
   if (g_slist_length(Glistdrives)==0) Glistdrives = NULL;
 }
 
-void get_current_matos(gboolean *Areadcd, gboolean *Awritecdr, gboolean *Awritecdrw, gboolean *Areaddvd, gboolean *Awritedvd)
+void matos_get_current_matos(gboolean *Areadcd, gboolean *Awritecdr, gboolean *Awritecdrw, gboolean *Areaddvd, gboolean *Awritedvd)
 {
   GSList *Lcur;
   Tdriveinfo *Ldrive;
@@ -118,7 +118,7 @@ void get_current_matos(gboolean *Areadcd, gboolean *Awritecdr, gboolean *Awritec
   }
 }
 
-void insert_or_update_drive(gchar *Adev, gchar *Amarque, gchar *Amodel, gchar *Aquoi, Tsearchdrive *Adrivedesc)
+void matos_insert_or_update_drive(gchar *Adev, gchar *Amarque, gchar *Amodel, gchar *Aquoi, Tsearchdrive *Adrivedesc)
 {
   /* on commence par construire l'identifiant */
   gchar *Lident = g_strdup_printf("%s %s %s", Amarque, Amodel, Aquoi);
@@ -151,14 +151,15 @@ _DEB("le bus en question [%s] = [%s]\n", Adrivedesc->bus, Adev);
   Ldrive->bus = g_slist_append(Ldrive->bus, g_strdup(Adrivedesc->bus));
   Ldrive->dev = g_slist_append(Ldrive->dev,
       g_strdup_printf("%s%s", Adrivedesc->useline,
-        strcmp(Adrivedesc->bus, "IDE") && strcmp(Adrivedesc->bus, "DSCSI") ? Adev : ""));
+        strcmp(Adrivedesc->bus, "IDE") && strncmp(Adrivedesc->bus, IDENT_SCSI, strlen(IDENT_SCSI)) ? 
+          Adev : ""));
 }
 
 /* operation de copie */
 gboolean burn_copy(Tgrave *Ag, GError **Aerror)
 {
-  Tdriveinfo *Lsource = get_drive_info(Ag, "srccopycombo");
-  Tdriveinfo *Lgraveur = get_drive_info(Ag, "dstcopycombo");
+  Tdriveinfo *Lsource = matos_get_drive_info(Ag, "srccopycombo");
+  Tdriveinfo *Lgraveur = matos_get_drive_info(Ag, "dstcopycombo");
   GtkEntry *Llecteuriso = GTK_ENTRY(sc_grave_get_widget(Ag, "srccopybtnvalue"));
   GtkEntry *Lgraveuriso = GTK_ENTRY(sc_grave_get_widget(Ag, "dstcopybtnvalue"));
   gchar *Ltxt;
@@ -314,7 +315,7 @@ gboolean burn_data(Tgrave *Ag, GError **Aerror)
   gint Ltodo = gtk_spin_button_get_value(GTK_SPIN_BUTTON(sc_grave_get_widget(Ag, "nbrcddata")));
   gboolean Lsimul = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(sc_grave_get_widget(Ag, "datasimul")));
   GtkEntry *Lgraveuriso = GTK_ENTRY(sc_grave_get_widget(Ag, "dstdatabtnvalue"));
-  Tdriveinfo *Lgraveur = get_drive_info(Ag, "dstdatacombo");
+  Tdriveinfo *Lgraveur = matos_get_drive_info(Ag, "dstdatacombo");
   gboolean *Labort = sc_grave_get_data(Ag, "gabort");
   gint Ldone = 1;
   gchar Ltmpdir[MAXPATHLEN] = "";
@@ -492,7 +493,7 @@ gboolean burn_dvddata(Tgrave *Ag, GError **Aerror)
   gint Ltodo = gtk_spin_button_get_value(GTK_SPIN_BUTTON(sc_grave_get_widget(Ag, "nbrdvddata")));
   gboolean Lsimul = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(sc_grave_get_widget(Ag, "dvddatasimul")));
   GtkEntry *Lgraveuriso = GTK_ENTRY(sc_grave_get_widget(Ag, "dstdvddatabtnvalue"));
-  Tdriveinfo *Lgraveur = get_drive_info(Ag, "dstdvddatacombo");
+  Tdriveinfo *Lgraveur = matos_get_drive_info(Ag, "dstdvddatacombo");
   gint Ldone = 1;
   gchar Ltmpdir[MAXPATHLEN] = "";
   gchar *Lextrapara = NULL;
@@ -619,6 +620,7 @@ gboolean callback_waiting_for_user(gpointer Adata)
     gdk_flush ();
     *Linitdisp = FALSE;
   }
+  matos_umount_device(Ldrive, NULL);
    
  _DEB("le premier avant le dvd [%d]", Lmedialu); 
   Lmedialu += get_dvdinfo(Lg, Ldrive, NULL);
@@ -664,6 +666,7 @@ gboolean waiting_for_user(gint Atitle, Tgrave *Ag, GSList *Arequiscd1, gint *Ade
   
   g_assert(Lwaitg);
   
+  gtk_image_set_from_pixbuf(GTK_IMAGE(sc_grave_get_widget(Lwaitg, "imgwaiting")), get_image("CDRWIcon"));
   Lwindow = GTK_WIDGET(sc_grave_get_widget(Lwaitg, "window_waiting_cd"));
   g_signal_connect(G_OBJECT(sc_grave_get_widget(Lwaitg, "cancelbutton")), "clicked", G_CALLBACK(abort_encours), Lwaitg);
 
@@ -713,12 +716,12 @@ gboolean waiting_for_user(gint Atitle, Tgrave *Ag, GSList *Arequiscd1, gint *Ade
   return (Lcont == 0 && Labort == FALSE);
 }
 
-Tdriveinfo *get_drive_info(Tgrave *Ag, gchar *Aname)
+Tdriveinfo *matos_get_drive_info(Tgrave *Ag, gchar *Aname)
 {
   return get_combo_value(sc_grave_get_widget(Ag, Aname));
 }
 
-gchar *get_dvdrwtools_bus(Tdriveinfo *Adrive)
+gchar *matos_get_device(Tdriveinfo *Adrive)
 {
   GSList *Lcur;
   gchar *Lcurbus;
@@ -727,7 +730,7 @@ gchar *get_dvdrwtools_bus(Tdriveinfo *Adrive)
   for (Lcur = Adrive->bus; Lcur; Lcur = g_slist_next(Lcur), i++) {
     Lcurbus = (gchar *) Lcur->data;
 
-    if (!strcmp(Lcurbus, "IDE") || !strcmp(Lcurbus, "DSCSI")) {
+    if (!strcmp(Lcurbus, "IDE") || !strncmp(Lcurbus, IDENT_SCSI, strlen(IDENT_SCSI)) || !strcmp(Lcurbus, "MANU")) {
       return g_slist_nth_data(Adrive->dev, i);
     }
   }
@@ -735,7 +738,7 @@ gchar *get_dvdrwtools_bus(Tdriveinfo *Adrive)
   return NULL;
 }
 
-gboolean is_an_iso(Tgrave *Ag, gchar *Aname)
+gboolean matos_is_an_iso(Tgrave *Ag, gchar *Aname)
 {
   Tdriveinfo *Ldrive = get_combo_value(sc_grave_get_widget(Ag, Aname));
 
@@ -761,6 +764,66 @@ GSList *manage_mediarequis(GSList *Acurlist, ...)
   return Lcurlist;
 }
 
+/* try to umount device when it's mounted
+ * scan /etc/ftab file to do this */
+gboolean matos_umount_device(Tdriveinfo *Adrive, GError **Aerror)
+{
+  gchar *Lcontent = NULL;
+  gint i;
+  gchar **Larrbuf, *Lcur, *s, *Lcurdev = NULL;
+  gchar Lcommand[_BUF_SIZE];
+  GSList *Llistdev;
+  gboolean Lfind = FALSE, Lstatus = FALSE;
+
+  if (!g_file_get_contents("/etc/mtab", &Lcontent, NULL, Aerror) || !Lcontent) return FALSE;
+  Larrbuf = g_strsplit(Lcontent, "\n", 0);
+
+  for (i=0; Larrbuf[i] && !Lfind; i++) {
+    s = Lcur = Larrbuf[i];
+    if (!*Lcur) continue;
+
+  _DEB("deb => [%s]", Lcur);
+
+    while (g_ascii_isalnum(*s) || *s=='/') s++;
+    *s=0;
+    if ((s=strchr(Lcur, '='))) Lcur=s+1;
+
+    for (Llistdev = Adrive->dev; Llistdev; Llistdev = g_slist_next(Llistdev)) {
+      Lcurdev = (gchar *) Llistdev->data;
+_DEB("comp de [%s] et [%s]", Lcurdev,Lcur);
+      if (!strcmp(Lcurdev, Lcur)) {
+        Lfind = TRUE;
+        break;
+      }
+    }
+  }
+
+  if (Lfind && Lcurdev) {
+    g_snprintf(Lcommand, sizeof(Lcommand)-1, "/bin/umount %s", Lcurdev);
+
+    _DEB("try to umount [%s]", Lcommand);
+
+    Lstatus = g_spawn_command_line_async(Lcommand, Aerror);
+  }
+
+  g_strfreev(Larrbuf);
+  g_free(Lcontent);
+
+  return Lstatus;
+}
+
+gboolean matos_maj_drive_info(Tdriveinfo *Adrive, gchar *Adev, GError **Aerror)
+{
+  Adrive->type = 0;
+
+  cdrecord_maj_drive_info(Adrive, Adev, Aerror);
+
+  /* use /proc/sys/dev/cdrom/info with linux to detect DVD capability */
+  proc_maj_drive_info(Adrive, Aerror);
+
+  return TRUE;
+}
+
 /*
  * vim:et:ts=8:sts=2:sw=2
  */
