@@ -83,9 +83,11 @@ gchar *make_image_getextrapara(Tgrave *Ag, gchar *Aop)
       gboolean *Luseautoblank = (gboolean *) sc_grave_get_data(Ag, "useautoblank");
 
       if (*Luseautoblank == FALSE) {
-        Tdriveinfo *Ldevice = get_drive_info(Ag, "dstdatacombo");
-        Lmediainfo = cdrecord_get_mediainfo(Ag, Ldevice, NULL);
-        Ldevchar = DRIVE_DEV(Ldevice);
+        Tdriveinfo *Ldevice = matos_get_drive_info(Ag, "dstdatacombo");
+        if (Ldevice) {
+          Ldevchar = DRIVE_DEV(Ldevice);
+          Lmediainfo = cdrecord_get_mediainfo(Ag, Ldevice, NULL);
+        }
       }
     }
 
