@@ -113,20 +113,45 @@ gboolean graveman_init(gint Aargc, gchar *Aargv[]) {
           );
       return FALSE;
     } else if (*ptr == 'h') {
-      g_printf("%s %s\n", PACKAGE, VERSION); 
+      g_printf("%s! %s\n", PACKAGE, VERSION); 
       g_printf(_("By Sylvain Cresto <scresto@gmail.com>\n\n"));
       g_printf("  %s %s %s\n"
-               "\t-v\t%s\n"
-               "\t-V\t%s\n"
-               "\t-s\t%s\n\n",
+               "\t-v\t\t%s\n"
+               "\t-V\t\t%s\n"
+               "\t-s\t\t%s\n"
+               "\t-c <%s>\t%s\n"
+               "\t-D <%s>\t%s\n"
+               "\t-t <%s>\t%s\n\t  %s\n\n  %s\n\n",
                _("Usage:"), Aargv[0], _("[options]"), _("show version number."),
-               _("show compilation informations."), _("always scan devices on startup"));
+               _("show compilation informations."), _("always scan devices on startup."),
+               _("files..."),
+               _("define preference-ordered set of extra configuration files to use in priority."),
+               _("dir..."),
+               _("define preference-ordered set of extra data directories to use in priority."),
+               _("themes..."),
+               _("define preference-ordered set of theme to use."),
+               _("\t\tconfiguration files, data directories and themes should be separated with a colon ':'."),
+               _("Type \"man graveman\" to get more informations."));
       return FALSE;
     } else if (*ptr == 's') {
       param_store_value("scan_drives", "1");
+    } else if (*ptr == 'c') {
+      if (++i<=Aargc) {
+        param_store_value("config_file", Aargv[i-1]);
+      } else {
+        g_warning(_("ignoring invalid %s parameter without file.\n"), Aargv[i-2]);
+      }
+    } else if (*ptr == 'D' || (!strcmp(ptr, "data"))) {
+      if (++i<=Aargc) {
+        param_store_value("data_file", Aargv[i-1]);
+      } else {
+        g_warning(_("ignoring invalid %s parameter without file.\n"), Aargv[i-2]);
+      }
     }
   }
 
+  /* appel a sc_init() dans support.c */
+  sc_init();
   return TRUE;
 }
 
