@@ -1,5 +1,5 @@
 /* support.c
- * Copyright (C) 2004, 2005 Sylvain Cresto <scresto@gmail.com>
+ * Copyright (C) 2004, 2005, 2006 Sylvain Cresto <scresto@gmail.com>
  * 
  * This file is part of graveman!
  *
@@ -168,7 +168,9 @@ Tgrave *sc_grave_destroy(Tgrave *Agrave)
 {
   g_return_val_if_fail(Agrave != NULL, NULL);
 
-  g_free(Agrave->xml);
+  if (Agrave->xml != NULL) {
+    g_object_unref(Agrave->xml);
+  }
   if (Agrave->data) g_hash_table_destroy(Agrave->data);
 
   g_free(Agrave);
